"use strict";

var _tap = require("tap");

var _snabbdomToHtml = require("snabbdom-to-html");

var _snabbdomToHtml2 = _interopRequireDefault(_snabbdomToHtml);

var _init = require("snabbdom-to-html/init");

var _init2 = _interopRequireDefault(_init);

var _modules = require("snabbdom-to-html/modules");

var _modules2 = _interopRequireDefault(_modules);

var _ = require("./");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable flowtype/require-parameter-type, flowtype/require-return-type, no-undefined, max-lines */
/* istanbul ignore file */
var toHTMLWithPlugins = (0, _init2.default)([_modules2.default.class, _modules2.default.props, _modules2.default.attributes, _modules2.default.style]);

(0, _tap.test)("empty", function (_ref) {
  var similar = _ref.similar,
      end = _ref.end;

  similar((0, _.a)(), { sel: "a" });
  end();
});

(0, _tap.test)("selector", function (_ref2) {
  var similar = _ref2.similar,
      end = _ref2.end;

  similar((0, _.a)({ selector: ".value" }), { sel: "a.value" });
  end();
});

(0, _tap.test)("children string", function (_ref3) {
  var similar = _ref3.similar,
      end = _ref3.end;

  similar((0, _.a)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref4) {
  var similar = _ref4.similar,
      end = _ref4.end;

  similar((0, _.a)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref5) {
  var similar = _ref5.similar,
      end = _ref5.end;

  similar((0, _.a)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref6) {
  var similar = _ref6.similar,
      end = _ref6.end;

  similar((0, _.a)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref7) {
  var similar = _ref7.similar,
      end = _ref7.end;

  similar((0, _.a)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref8) {
  var similar = _ref8.similar,
      end = _ref8.end;

  similar((0, _.a)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref9) {
  var similar = _ref9.similar,
      end = _ref9.end;

  similar((0, _.a)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "a#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref10) {
  var equal = _ref10.equal,
      end = _ref10.end;

  equal((0, _snabbdomToHtml2.default)((0, _.a)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<a id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</a>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref11) {
  var equal = _ref11.equal,
      end = _ref11.end;

  equal(toHTMLWithPlugins((0, _.a)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<a id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</a>");
  end();
});

(0, _tap.test)("empty", function (_ref12) {
  var similar = _ref12.similar,
      end = _ref12.end;

  similar((0, _.abbr)(), { sel: "abbr" });
  end();
});

(0, _tap.test)("selector", function (_ref13) {
  var similar = _ref13.similar,
      end = _ref13.end;

  similar((0, _.abbr)({ selector: ".value" }), { sel: "abbr.value" });
  end();
});

(0, _tap.test)("children string", function (_ref14) {
  var similar = _ref14.similar,
      end = _ref14.end;

  similar((0, _.abbr)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref15) {
  var similar = _ref15.similar,
      end = _ref15.end;

  similar((0, _.abbr)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref16) {
  var similar = _ref16.similar,
      end = _ref16.end;

  similar((0, _.abbr)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref17) {
  var similar = _ref17.similar,
      end = _ref17.end;

  similar((0, _.abbr)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref18) {
  var similar = _ref18.similar,
      end = _ref18.end;

  similar((0, _.abbr)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref19) {
  var similar = _ref19.similar,
      end = _ref19.end;

  similar((0, _.abbr)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref20) {
  var similar = _ref20.similar,
      end = _ref20.end;

  similar((0, _.abbr)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "abbr#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref21) {
  var equal = _ref21.equal,
      end = _ref21.end;

  equal((0, _snabbdomToHtml2.default)((0, _.abbr)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<abbr id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</abbr>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref22) {
  var equal = _ref22.equal,
      end = _ref22.end;

  equal(toHTMLWithPlugins((0, _.abbr)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<abbr id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</abbr>");
  end();
});

(0, _tap.test)("empty", function (_ref23) {
  var similar = _ref23.similar,
      end = _ref23.end;

  similar((0, _.address)(), { sel: "address" });
  end();
});

(0, _tap.test)("selector", function (_ref24) {
  var similar = _ref24.similar,
      end = _ref24.end;

  similar((0, _.address)({ selector: ".value" }), { sel: "address.value" });
  end();
});

(0, _tap.test)("children string", function (_ref25) {
  var similar = _ref25.similar,
      end = _ref25.end;

  similar((0, _.address)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref26) {
  var similar = _ref26.similar,
      end = _ref26.end;

  similar((0, _.address)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref27) {
  var similar = _ref27.similar,
      end = _ref27.end;

  similar((0, _.address)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref28) {
  var similar = _ref28.similar,
      end = _ref28.end;

  similar((0, _.address)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref29) {
  var similar = _ref29.similar,
      end = _ref29.end;

  similar((0, _.address)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref30) {
  var similar = _ref30.similar,
      end = _ref30.end;

  similar((0, _.address)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref31) {
  var similar = _ref31.similar,
      end = _ref31.end;

  similar((0, _.address)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "address#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref32) {
  var equal = _ref32.equal,
      end = _ref32.end;

  equal((0, _snabbdomToHtml2.default)((0, _.address)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<address id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</address>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref33) {
  var equal = _ref33.equal,
      end = _ref33.end;

  equal(toHTMLWithPlugins((0, _.address)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<address id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</address>");
  end();
});

(0, _tap.test)("empty", function (_ref34) {
  var similar = _ref34.similar,
      end = _ref34.end;

  similar((0, _.article)(), { sel: "article" });
  end();
});

(0, _tap.test)("selector", function (_ref35) {
  var similar = _ref35.similar,
      end = _ref35.end;

  similar((0, _.article)({ selector: ".value" }), { sel: "article.value" });
  end();
});

(0, _tap.test)("children string", function (_ref36) {
  var similar = _ref36.similar,
      end = _ref36.end;

  similar((0, _.article)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref37) {
  var similar = _ref37.similar,
      end = _ref37.end;

  similar((0, _.article)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref38) {
  var similar = _ref38.similar,
      end = _ref38.end;

  similar((0, _.article)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref39) {
  var similar = _ref39.similar,
      end = _ref39.end;

  similar((0, _.article)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref40) {
  var similar = _ref40.similar,
      end = _ref40.end;

  similar((0, _.article)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref41) {
  var similar = _ref41.similar,
      end = _ref41.end;

  similar((0, _.article)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref42) {
  var similar = _ref42.similar,
      end = _ref42.end;

  similar((0, _.article)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "article#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref43) {
  var equal = _ref43.equal,
      end = _ref43.end;

  equal((0, _snabbdomToHtml2.default)((0, _.article)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<article id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</article>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref44) {
  var equal = _ref44.equal,
      end = _ref44.end;

  equal(toHTMLWithPlugins((0, _.article)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<article id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</article>");
  end();
});

(0, _tap.test)("empty", function (_ref45) {
  var similar = _ref45.similar,
      end = _ref45.end;

  similar((0, _.aside)(), { sel: "aside" });
  end();
});

(0, _tap.test)("selector", function (_ref46) {
  var similar = _ref46.similar,
      end = _ref46.end;

  similar((0, _.aside)({ selector: ".value" }), { sel: "aside.value" });
  end();
});

(0, _tap.test)("children string", function (_ref47) {
  var similar = _ref47.similar,
      end = _ref47.end;

  similar((0, _.aside)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref48) {
  var similar = _ref48.similar,
      end = _ref48.end;

  similar((0, _.aside)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref49) {
  var similar = _ref49.similar,
      end = _ref49.end;

  similar((0, _.aside)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref50) {
  var similar = _ref50.similar,
      end = _ref50.end;

  similar((0, _.aside)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref51) {
  var similar = _ref51.similar,
      end = _ref51.end;

  similar((0, _.aside)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref52) {
  var similar = _ref52.similar,
      end = _ref52.end;

  similar((0, _.aside)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref53) {
  var similar = _ref53.similar,
      end = _ref53.end;

  similar((0, _.aside)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "aside#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref54) {
  var equal = _ref54.equal,
      end = _ref54.end;

  equal((0, _snabbdomToHtml2.default)((0, _.aside)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<aside id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</aside>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref55) {
  var equal = _ref55.equal,
      end = _ref55.end;

  equal(toHTMLWithPlugins((0, _.aside)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<aside id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</aside>");
  end();
});

(0, _tap.test)("empty", function (_ref56) {
  var similar = _ref56.similar,
      end = _ref56.end;

  similar((0, _.audio)(), { sel: "audio" });
  end();
});

(0, _tap.test)("selector", function (_ref57) {
  var similar = _ref57.similar,
      end = _ref57.end;

  similar((0, _.audio)({ selector: ".value" }), { sel: "audio.value" });
  end();
});

(0, _tap.test)("children string", function (_ref58) {
  var similar = _ref58.similar,
      end = _ref58.end;

  similar((0, _.audio)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref59) {
  var similar = _ref59.similar,
      end = _ref59.end;

  similar((0, _.audio)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref60) {
  var similar = _ref60.similar,
      end = _ref60.end;

  similar((0, _.audio)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref61) {
  var similar = _ref61.similar,
      end = _ref61.end;

  similar((0, _.audio)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref62) {
  var similar = _ref62.similar,
      end = _ref62.end;

  similar((0, _.audio)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref63) {
  var similar = _ref63.similar,
      end = _ref63.end;

  similar((0, _.audio)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref64) {
  var similar = _ref64.similar,
      end = _ref64.end;

  similar((0, _.audio)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "audio#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref65) {
  var equal = _ref65.equal,
      end = _ref65.end;

  equal((0, _snabbdomToHtml2.default)((0, _.audio)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<audio id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</audio>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref66) {
  var equal = _ref66.equal,
      end = _ref66.end;

  equal(toHTMLWithPlugins((0, _.audio)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<audio id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</audio>");
  end();
});

(0, _tap.test)("empty", function (_ref67) {
  var similar = _ref67.similar,
      end = _ref67.end;

  similar((0, _.b)(), { sel: "b" });
  end();
});

(0, _tap.test)("selector", function (_ref68) {
  var similar = _ref68.similar,
      end = _ref68.end;

  similar((0, _.b)({ selector: ".value" }), { sel: "b.value" });
  end();
});

(0, _tap.test)("children string", function (_ref69) {
  var similar = _ref69.similar,
      end = _ref69.end;

  similar((0, _.b)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref70) {
  var similar = _ref70.similar,
      end = _ref70.end;

  similar((0, _.b)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref71) {
  var similar = _ref71.similar,
      end = _ref71.end;

  similar((0, _.b)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref72) {
  var similar = _ref72.similar,
      end = _ref72.end;

  similar((0, _.b)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref73) {
  var similar = _ref73.similar,
      end = _ref73.end;

  similar((0, _.b)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref74) {
  var similar = _ref74.similar,
      end = _ref74.end;

  similar((0, _.b)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref75) {
  var similar = _ref75.similar,
      end = _ref75.end;

  similar((0, _.b)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "b#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref76) {
  var equal = _ref76.equal,
      end = _ref76.end;

  equal((0, _snabbdomToHtml2.default)((0, _.b)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<b id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</b>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref77) {
  var equal = _ref77.equal,
      end = _ref77.end;

  equal(toHTMLWithPlugins((0, _.b)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<b id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</b>");
  end();
});

(0, _tap.test)("empty", function (_ref78) {
  var similar = _ref78.similar,
      end = _ref78.end;

  similar((0, _.bdi)(), { sel: "bdi" });
  end();
});

(0, _tap.test)("selector", function (_ref79) {
  var similar = _ref79.similar,
      end = _ref79.end;

  similar((0, _.bdi)({ selector: ".value" }), { sel: "bdi.value" });
  end();
});

(0, _tap.test)("children string", function (_ref80) {
  var similar = _ref80.similar,
      end = _ref80.end;

  similar((0, _.bdi)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref81) {
  var similar = _ref81.similar,
      end = _ref81.end;

  similar((0, _.bdi)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref82) {
  var similar = _ref82.similar,
      end = _ref82.end;

  similar((0, _.bdi)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref83) {
  var similar = _ref83.similar,
      end = _ref83.end;

  similar((0, _.bdi)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref84) {
  var similar = _ref84.similar,
      end = _ref84.end;

  similar((0, _.bdi)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref85) {
  var similar = _ref85.similar,
      end = _ref85.end;

  similar((0, _.bdi)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref86) {
  var similar = _ref86.similar,
      end = _ref86.end;

  similar((0, _.bdi)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "bdi#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref87) {
  var equal = _ref87.equal,
      end = _ref87.end;

  equal((0, _snabbdomToHtml2.default)((0, _.bdi)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<bdi id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</bdi>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref88) {
  var equal = _ref88.equal,
      end = _ref88.end;

  equal(toHTMLWithPlugins((0, _.bdi)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<bdi id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</bdi>");
  end();
});

(0, _tap.test)("empty", function (_ref89) {
  var similar = _ref89.similar,
      end = _ref89.end;

  similar((0, _.bdo)(), { sel: "bdo" });
  end();
});

(0, _tap.test)("selector", function (_ref90) {
  var similar = _ref90.similar,
      end = _ref90.end;

  similar((0, _.bdo)({ selector: ".value" }), { sel: "bdo.value" });
  end();
});

(0, _tap.test)("children string", function (_ref91) {
  var similar = _ref91.similar,
      end = _ref91.end;

  similar((0, _.bdo)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref92) {
  var similar = _ref92.similar,
      end = _ref92.end;

  similar((0, _.bdo)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref93) {
  var similar = _ref93.similar,
      end = _ref93.end;

  similar((0, _.bdo)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref94) {
  var similar = _ref94.similar,
      end = _ref94.end;

  similar((0, _.bdo)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref95) {
  var similar = _ref95.similar,
      end = _ref95.end;

  similar((0, _.bdo)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref96) {
  var similar = _ref96.similar,
      end = _ref96.end;

  similar((0, _.bdo)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref97) {
  var similar = _ref97.similar,
      end = _ref97.end;

  similar((0, _.bdo)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "bdo#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref98) {
  var equal = _ref98.equal,
      end = _ref98.end;

  equal((0, _snabbdomToHtml2.default)((0, _.bdo)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<bdo id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</bdo>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref99) {
  var equal = _ref99.equal,
      end = _ref99.end;

  equal(toHTMLWithPlugins((0, _.bdo)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<bdo id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</bdo>");
  end();
});

(0, _tap.test)("empty", function (_ref100) {
  var similar = _ref100.similar,
      end = _ref100.end;

  similar((0, _.bgsound)(), { sel: "bgsound" });
  end();
});

(0, _tap.test)("selector", function (_ref101) {
  var similar = _ref101.similar,
      end = _ref101.end;

  similar((0, _.bgsound)({ selector: ".value" }), { sel: "bgsound.value" });
  end();
});

(0, _tap.test)("children string", function (_ref102) {
  var similar = _ref102.similar,
      end = _ref102.end;

  similar((0, _.bgsound)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref103) {
  var similar = _ref103.similar,
      end = _ref103.end;

  similar((0, _.bgsound)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref104) {
  var similar = _ref104.similar,
      end = _ref104.end;

  similar((0, _.bgsound)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref105) {
  var similar = _ref105.similar,
      end = _ref105.end;

  similar((0, _.bgsound)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref106) {
  var similar = _ref106.similar,
      end = _ref106.end;

  similar((0, _.bgsound)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref107) {
  var similar = _ref107.similar,
      end = _ref107.end;

  similar((0, _.bgsound)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref108) {
  var similar = _ref108.similar,
      end = _ref108.end;

  similar((0, _.bgsound)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "bgsound#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref109) {
  var equal = _ref109.equal,
      end = _ref109.end;

  equal((0, _snabbdomToHtml2.default)((0, _.bgsound)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<bgsound id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</bgsound>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref110) {
  var equal = _ref110.equal,
      end = _ref110.end;

  equal(toHTMLWithPlugins((0, _.bgsound)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<bgsound id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</bgsound>");
  end();
});

(0, _tap.test)("empty", function (_ref111) {
  var similar = _ref111.similar,
      end = _ref111.end;

  similar((0, _.blockquote)(), { sel: "blockquote" });
  end();
});

(0, _tap.test)("selector", function (_ref112) {
  var similar = _ref112.similar,
      end = _ref112.end;

  similar((0, _.blockquote)({ selector: ".value" }), { sel: "blockquote.value" });
  end();
});

(0, _tap.test)("children string", function (_ref113) {
  var similar = _ref113.similar,
      end = _ref113.end;

  similar((0, _.blockquote)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref114) {
  var similar = _ref114.similar,
      end = _ref114.end;

  similar((0, _.blockquote)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref115) {
  var similar = _ref115.similar,
      end = _ref115.end;

  similar((0, _.blockquote)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref116) {
  var similar = _ref116.similar,
      end = _ref116.end;

  similar((0, _.blockquote)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref117) {
  var similar = _ref117.similar,
      end = _ref117.end;

  similar((0, _.blockquote)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref118) {
  var similar = _ref118.similar,
      end = _ref118.end;

  similar((0, _.blockquote)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref119) {
  var similar = _ref119.similar,
      end = _ref119.end;

  similar((0, _.blockquote)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "blockquote#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref120) {
  var equal = _ref120.equal,
      end = _ref120.end;

  equal((0, _snabbdomToHtml2.default)((0, _.blockquote)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<blockquote id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</blockquote>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref121) {
  var equal = _ref121.equal,
      end = _ref121.end;

  equal(toHTMLWithPlugins((0, _.blockquote)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<blockquote id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</blockquote>");
  end();
});

(0, _tap.test)("empty", function (_ref122) {
  var similar = _ref122.similar,
      end = _ref122.end;

  similar((0, _.body)(), { sel: "body" });
  end();
});

(0, _tap.test)("selector", function (_ref123) {
  var similar = _ref123.similar,
      end = _ref123.end;

  similar((0, _.body)({ selector: ".value" }), { sel: "body.value" });
  end();
});

(0, _tap.test)("children string", function (_ref124) {
  var similar = _ref124.similar,
      end = _ref124.end;

  similar((0, _.body)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref125) {
  var similar = _ref125.similar,
      end = _ref125.end;

  similar((0, _.body)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref126) {
  var similar = _ref126.similar,
      end = _ref126.end;

  similar((0, _.body)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref127) {
  var similar = _ref127.similar,
      end = _ref127.end;

  similar((0, _.body)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref128) {
  var similar = _ref128.similar,
      end = _ref128.end;

  similar((0, _.body)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref129) {
  var similar = _ref129.similar,
      end = _ref129.end;

  similar((0, _.body)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref130) {
  var similar = _ref130.similar,
      end = _ref130.end;

  similar((0, _.body)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "body#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref131) {
  var equal = _ref131.equal,
      end = _ref131.end;

  equal((0, _snabbdomToHtml2.default)((0, _.body)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<body id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</body>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref132) {
  var equal = _ref132.equal,
      end = _ref132.end;

  equal(toHTMLWithPlugins((0, _.body)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<body id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</body>");
  end();
});

(0, _tap.test)("empty", function (_ref133) {
  var similar = _ref133.similar,
      end = _ref133.end;

  similar((0, _.button)(), { sel: "button" });
  end();
});

(0, _tap.test)("selector", function (_ref134) {
  var similar = _ref134.similar,
      end = _ref134.end;

  similar((0, _.button)({ selector: ".value" }), { sel: "button.value" });
  end();
});

(0, _tap.test)("children string", function (_ref135) {
  var similar = _ref135.similar,
      end = _ref135.end;

  similar((0, _.button)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref136) {
  var similar = _ref136.similar,
      end = _ref136.end;

  similar((0, _.button)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref137) {
  var similar = _ref137.similar,
      end = _ref137.end;

  similar((0, _.button)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref138) {
  var similar = _ref138.similar,
      end = _ref138.end;

  similar((0, _.button)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref139) {
  var similar = _ref139.similar,
      end = _ref139.end;

  similar((0, _.button)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref140) {
  var similar = _ref140.similar,
      end = _ref140.end;

  similar((0, _.button)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref141) {
  var similar = _ref141.similar,
      end = _ref141.end;

  similar((0, _.button)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "button#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref142) {
  var equal = _ref142.equal,
      end = _ref142.end;

  equal((0, _snabbdomToHtml2.default)((0, _.button)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<button id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</button>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref143) {
  var equal = _ref143.equal,
      end = _ref143.end;

  equal(toHTMLWithPlugins((0, _.button)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<button id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</button>");
  end();
});

(0, _tap.test)("empty", function (_ref144) {
  var similar = _ref144.similar,
      end = _ref144.end;

  similar((0, _.canvas)(), { sel: "canvas" });
  end();
});

(0, _tap.test)("selector", function (_ref145) {
  var similar = _ref145.similar,
      end = _ref145.end;

  similar((0, _.canvas)({ selector: ".value" }), { sel: "canvas.value" });
  end();
});

(0, _tap.test)("children string", function (_ref146) {
  var similar = _ref146.similar,
      end = _ref146.end;

  similar((0, _.canvas)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref147) {
  var similar = _ref147.similar,
      end = _ref147.end;

  similar((0, _.canvas)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref148) {
  var similar = _ref148.similar,
      end = _ref148.end;

  similar((0, _.canvas)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref149) {
  var similar = _ref149.similar,
      end = _ref149.end;

  similar((0, _.canvas)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref150) {
  var similar = _ref150.similar,
      end = _ref150.end;

  similar((0, _.canvas)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref151) {
  var similar = _ref151.similar,
      end = _ref151.end;

  similar((0, _.canvas)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref152) {
  var similar = _ref152.similar,
      end = _ref152.end;

  similar((0, _.canvas)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "canvas#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref153) {
  var equal = _ref153.equal,
      end = _ref153.end;

  equal((0, _snabbdomToHtml2.default)((0, _.canvas)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<canvas id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</canvas>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref154) {
  var equal = _ref154.equal,
      end = _ref154.end;

  equal(toHTMLWithPlugins((0, _.canvas)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<canvas id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</canvas>");
  end();
});

(0, _tap.test)("empty", function (_ref155) {
  var similar = _ref155.similar,
      end = _ref155.end;

  similar((0, _.caption)(), { sel: "caption" });
  end();
});

(0, _tap.test)("selector", function (_ref156) {
  var similar = _ref156.similar,
      end = _ref156.end;

  similar((0, _.caption)({ selector: ".value" }), { sel: "caption.value" });
  end();
});

(0, _tap.test)("children string", function (_ref157) {
  var similar = _ref157.similar,
      end = _ref157.end;

  similar((0, _.caption)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref158) {
  var similar = _ref158.similar,
      end = _ref158.end;

  similar((0, _.caption)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref159) {
  var similar = _ref159.similar,
      end = _ref159.end;

  similar((0, _.caption)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref160) {
  var similar = _ref160.similar,
      end = _ref160.end;

  similar((0, _.caption)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref161) {
  var similar = _ref161.similar,
      end = _ref161.end;

  similar((0, _.caption)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref162) {
  var similar = _ref162.similar,
      end = _ref162.end;

  similar((0, _.caption)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref163) {
  var similar = _ref163.similar,
      end = _ref163.end;

  similar((0, _.caption)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "caption#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref164) {
  var equal = _ref164.equal,
      end = _ref164.end;

  equal((0, _snabbdomToHtml2.default)((0, _.caption)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<caption id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</caption>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref165) {
  var equal = _ref165.equal,
      end = _ref165.end;

  equal(toHTMLWithPlugins((0, _.caption)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<caption id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</caption>");
  end();
});

(0, _tap.test)("empty", function (_ref166) {
  var similar = _ref166.similar,
      end = _ref166.end;

  similar((0, _.cite)(), { sel: "cite" });
  end();
});

(0, _tap.test)("selector", function (_ref167) {
  var similar = _ref167.similar,
      end = _ref167.end;

  similar((0, _.cite)({ selector: ".value" }), { sel: "cite.value" });
  end();
});

(0, _tap.test)("children string", function (_ref168) {
  var similar = _ref168.similar,
      end = _ref168.end;

  similar((0, _.cite)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref169) {
  var similar = _ref169.similar,
      end = _ref169.end;

  similar((0, _.cite)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref170) {
  var similar = _ref170.similar,
      end = _ref170.end;

  similar((0, _.cite)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref171) {
  var similar = _ref171.similar,
      end = _ref171.end;

  similar((0, _.cite)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref172) {
  var similar = _ref172.similar,
      end = _ref172.end;

  similar((0, _.cite)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref173) {
  var similar = _ref173.similar,
      end = _ref173.end;

  similar((0, _.cite)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref174) {
  var similar = _ref174.similar,
      end = _ref174.end;

  similar((0, _.cite)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "cite#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref175) {
  var equal = _ref175.equal,
      end = _ref175.end;

  equal((0, _snabbdomToHtml2.default)((0, _.cite)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<cite id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</cite>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref176) {
  var equal = _ref176.equal,
      end = _ref176.end;

  equal(toHTMLWithPlugins((0, _.cite)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<cite id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</cite>");
  end();
});

(0, _tap.test)("empty", function (_ref177) {
  var similar = _ref177.similar,
      end = _ref177.end;

  similar((0, _.code)(), { sel: "code" });
  end();
});

(0, _tap.test)("selector", function (_ref178) {
  var similar = _ref178.similar,
      end = _ref178.end;

  similar((0, _.code)({ selector: ".value" }), { sel: "code.value" });
  end();
});

(0, _tap.test)("children string", function (_ref179) {
  var similar = _ref179.similar,
      end = _ref179.end;

  similar((0, _.code)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref180) {
  var similar = _ref180.similar,
      end = _ref180.end;

  similar((0, _.code)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref181) {
  var similar = _ref181.similar,
      end = _ref181.end;

  similar((0, _.code)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref182) {
  var similar = _ref182.similar,
      end = _ref182.end;

  similar((0, _.code)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref183) {
  var similar = _ref183.similar,
      end = _ref183.end;

  similar((0, _.code)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref184) {
  var similar = _ref184.similar,
      end = _ref184.end;

  similar((0, _.code)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref185) {
  var similar = _ref185.similar,
      end = _ref185.end;

  similar((0, _.code)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "code#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref186) {
  var equal = _ref186.equal,
      end = _ref186.end;

  equal((0, _snabbdomToHtml2.default)((0, _.code)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<code id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</code>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref187) {
  var equal = _ref187.equal,
      end = _ref187.end;

  equal(toHTMLWithPlugins((0, _.code)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<code id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</code>");
  end();
});

(0, _tap.test)("empty", function (_ref188) {
  var similar = _ref188.similar,
      end = _ref188.end;

  similar((0, _.colgroup)(), { sel: "colgroup" });
  end();
});

(0, _tap.test)("selector", function (_ref189) {
  var similar = _ref189.similar,
      end = _ref189.end;

  similar((0, _.colgroup)({ selector: ".value" }), { sel: "colgroup.value" });
  end();
});

(0, _tap.test)("children string", function (_ref190) {
  var similar = _ref190.similar,
      end = _ref190.end;

  similar((0, _.colgroup)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref191) {
  var similar = _ref191.similar,
      end = _ref191.end;

  similar((0, _.colgroup)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref192) {
  var similar = _ref192.similar,
      end = _ref192.end;

  similar((0, _.colgroup)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref193) {
  var similar = _ref193.similar,
      end = _ref193.end;

  similar((0, _.colgroup)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref194) {
  var similar = _ref194.similar,
      end = _ref194.end;

  similar((0, _.colgroup)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref195) {
  var similar = _ref195.similar,
      end = _ref195.end;

  similar((0, _.colgroup)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref196) {
  var similar = _ref196.similar,
      end = _ref196.end;

  similar((0, _.colgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "colgroup#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref197) {
  var equal = _ref197.equal,
      end = _ref197.end;

  equal((0, _snabbdomToHtml2.default)((0, _.colgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<colgroup id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</colgroup>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref198) {
  var equal = _ref198.equal,
      end = _ref198.end;

  equal(toHTMLWithPlugins((0, _.colgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<colgroup id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</colgroup>");
  end();
});

(0, _tap.test)("empty", function (_ref199) {
  var similar = _ref199.similar,
      end = _ref199.end;

  similar((0, _.data)(), { sel: "data" });
  end();
});

(0, _tap.test)("selector", function (_ref200) {
  var similar = _ref200.similar,
      end = _ref200.end;

  similar((0, _.data)({ selector: ".value" }), { sel: "data.value" });
  end();
});

(0, _tap.test)("children string", function (_ref201) {
  var similar = _ref201.similar,
      end = _ref201.end;

  similar((0, _.data)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref202) {
  var similar = _ref202.similar,
      end = _ref202.end;

  similar((0, _.data)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref203) {
  var similar = _ref203.similar,
      end = _ref203.end;

  similar((0, _.data)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref204) {
  var similar = _ref204.similar,
      end = _ref204.end;

  similar((0, _.data)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref205) {
  var similar = _ref205.similar,
      end = _ref205.end;

  similar((0, _.data)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref206) {
  var similar = _ref206.similar,
      end = _ref206.end;

  similar((0, _.data)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref207) {
  var similar = _ref207.similar,
      end = _ref207.end;

  similar((0, _.data)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "data#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref208) {
  var equal = _ref208.equal,
      end = _ref208.end;

  equal((0, _snabbdomToHtml2.default)((0, _.data)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<data id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</data>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref209) {
  var equal = _ref209.equal,
      end = _ref209.end;

  equal(toHTMLWithPlugins((0, _.data)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<data id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</data>");
  end();
});

(0, _tap.test)("empty", function (_ref210) {
  var similar = _ref210.similar,
      end = _ref210.end;

  similar((0, _.datalist)(), { sel: "datalist" });
  end();
});

(0, _tap.test)("selector", function (_ref211) {
  var similar = _ref211.similar,
      end = _ref211.end;

  similar((0, _.datalist)({ selector: ".value" }), { sel: "datalist.value" });
  end();
});

(0, _tap.test)("children string", function (_ref212) {
  var similar = _ref212.similar,
      end = _ref212.end;

  similar((0, _.datalist)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref213) {
  var similar = _ref213.similar,
      end = _ref213.end;

  similar((0, _.datalist)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref214) {
  var similar = _ref214.similar,
      end = _ref214.end;

  similar((0, _.datalist)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref215) {
  var similar = _ref215.similar,
      end = _ref215.end;

  similar((0, _.datalist)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref216) {
  var similar = _ref216.similar,
      end = _ref216.end;

  similar((0, _.datalist)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref217) {
  var similar = _ref217.similar,
      end = _ref217.end;

  similar((0, _.datalist)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref218) {
  var similar = _ref218.similar,
      end = _ref218.end;

  similar((0, _.datalist)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "datalist#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref219) {
  var equal = _ref219.equal,
      end = _ref219.end;

  equal((0, _snabbdomToHtml2.default)((0, _.datalist)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<datalist id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</datalist>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref220) {
  var equal = _ref220.equal,
      end = _ref220.end;

  equal(toHTMLWithPlugins((0, _.datalist)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<datalist id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</datalist>");
  end();
});

(0, _tap.test)("empty", function (_ref221) {
  var similar = _ref221.similar,
      end = _ref221.end;

  similar((0, _.dd)(), { sel: "dd" });
  end();
});

(0, _tap.test)("selector", function (_ref222) {
  var similar = _ref222.similar,
      end = _ref222.end;

  similar((0, _.dd)({ selector: ".value" }), { sel: "dd.value" });
  end();
});

(0, _tap.test)("children string", function (_ref223) {
  var similar = _ref223.similar,
      end = _ref223.end;

  similar((0, _.dd)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref224) {
  var similar = _ref224.similar,
      end = _ref224.end;

  similar((0, _.dd)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref225) {
  var similar = _ref225.similar,
      end = _ref225.end;

  similar((0, _.dd)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref226) {
  var similar = _ref226.similar,
      end = _ref226.end;

  similar((0, _.dd)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref227) {
  var similar = _ref227.similar,
      end = _ref227.end;

  similar((0, _.dd)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref228) {
  var similar = _ref228.similar,
      end = _ref228.end;

  similar((0, _.dd)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref229) {
  var similar = _ref229.similar,
      end = _ref229.end;

  similar((0, _.dd)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "dd#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref230) {
  var equal = _ref230.equal,
      end = _ref230.end;

  equal((0, _snabbdomToHtml2.default)((0, _.dd)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dd id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</dd>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref231) {
  var equal = _ref231.equal,
      end = _ref231.end;

  equal(toHTMLWithPlugins((0, _.dd)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dd id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</dd>");
  end();
});

(0, _tap.test)("empty", function (_ref232) {
  var similar = _ref232.similar,
      end = _ref232.end;

  similar((0, _.del)(), { sel: "del" });
  end();
});

(0, _tap.test)("selector", function (_ref233) {
  var similar = _ref233.similar,
      end = _ref233.end;

  similar((0, _.del)({ selector: ".value" }), { sel: "del.value" });
  end();
});

(0, _tap.test)("children string", function (_ref234) {
  var similar = _ref234.similar,
      end = _ref234.end;

  similar((0, _.del)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref235) {
  var similar = _ref235.similar,
      end = _ref235.end;

  similar((0, _.del)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref236) {
  var similar = _ref236.similar,
      end = _ref236.end;

  similar((0, _.del)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref237) {
  var similar = _ref237.similar,
      end = _ref237.end;

  similar((0, _.del)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref238) {
  var similar = _ref238.similar,
      end = _ref238.end;

  similar((0, _.del)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref239) {
  var similar = _ref239.similar,
      end = _ref239.end;

  similar((0, _.del)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref240) {
  var similar = _ref240.similar,
      end = _ref240.end;

  similar((0, _.del)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "del#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref241) {
  var equal = _ref241.equal,
      end = _ref241.end;

  equal((0, _snabbdomToHtml2.default)((0, _.del)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<del id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</del>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref242) {
  var equal = _ref242.equal,
      end = _ref242.end;

  equal(toHTMLWithPlugins((0, _.del)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<del id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</del>");
  end();
});

(0, _tap.test)("empty", function (_ref243) {
  var similar = _ref243.similar,
      end = _ref243.end;

  similar((0, _.details)(), { sel: "details" });
  end();
});

(0, _tap.test)("selector", function (_ref244) {
  var similar = _ref244.similar,
      end = _ref244.end;

  similar((0, _.details)({ selector: ".value" }), { sel: "details.value" });
  end();
});

(0, _tap.test)("children string", function (_ref245) {
  var similar = _ref245.similar,
      end = _ref245.end;

  similar((0, _.details)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref246) {
  var similar = _ref246.similar,
      end = _ref246.end;

  similar((0, _.details)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref247) {
  var similar = _ref247.similar,
      end = _ref247.end;

  similar((0, _.details)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref248) {
  var similar = _ref248.similar,
      end = _ref248.end;

  similar((0, _.details)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref249) {
  var similar = _ref249.similar,
      end = _ref249.end;

  similar((0, _.details)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref250) {
  var similar = _ref250.similar,
      end = _ref250.end;

  similar((0, _.details)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref251) {
  var similar = _ref251.similar,
      end = _ref251.end;

  similar((0, _.details)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "details#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref252) {
  var equal = _ref252.equal,
      end = _ref252.end;

  equal((0, _snabbdomToHtml2.default)((0, _.details)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<details id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</details>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref253) {
  var equal = _ref253.equal,
      end = _ref253.end;

  equal(toHTMLWithPlugins((0, _.details)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<details id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</details>");
  end();
});

(0, _tap.test)("empty", function (_ref254) {
  var similar = _ref254.similar,
      end = _ref254.end;

  similar((0, _.dfn)(), { sel: "dfn" });
  end();
});

(0, _tap.test)("selector", function (_ref255) {
  var similar = _ref255.similar,
      end = _ref255.end;

  similar((0, _.dfn)({ selector: ".value" }), { sel: "dfn.value" });
  end();
});

(0, _tap.test)("children string", function (_ref256) {
  var similar = _ref256.similar,
      end = _ref256.end;

  similar((0, _.dfn)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref257) {
  var similar = _ref257.similar,
      end = _ref257.end;

  similar((0, _.dfn)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref258) {
  var similar = _ref258.similar,
      end = _ref258.end;

  similar((0, _.dfn)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref259) {
  var similar = _ref259.similar,
      end = _ref259.end;

  similar((0, _.dfn)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref260) {
  var similar = _ref260.similar,
      end = _ref260.end;

  similar((0, _.dfn)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref261) {
  var similar = _ref261.similar,
      end = _ref261.end;

  similar((0, _.dfn)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref262) {
  var similar = _ref262.similar,
      end = _ref262.end;

  similar((0, _.dfn)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "dfn#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref263) {
  var equal = _ref263.equal,
      end = _ref263.end;

  equal((0, _snabbdomToHtml2.default)((0, _.dfn)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dfn id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</dfn>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref264) {
  var equal = _ref264.equal,
      end = _ref264.end;

  equal(toHTMLWithPlugins((0, _.dfn)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dfn id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</dfn>");
  end();
});

(0, _tap.test)("empty", function (_ref265) {
  var similar = _ref265.similar,
      end = _ref265.end;

  similar((0, _.dir)(), { sel: "dir" });
  end();
});

(0, _tap.test)("selector", function (_ref266) {
  var similar = _ref266.similar,
      end = _ref266.end;

  similar((0, _.dir)({ selector: ".value" }), { sel: "dir.value" });
  end();
});

(0, _tap.test)("children string", function (_ref267) {
  var similar = _ref267.similar,
      end = _ref267.end;

  similar((0, _.dir)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref268) {
  var similar = _ref268.similar,
      end = _ref268.end;

  similar((0, _.dir)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref269) {
  var similar = _ref269.similar,
      end = _ref269.end;

  similar((0, _.dir)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref270) {
  var similar = _ref270.similar,
      end = _ref270.end;

  similar((0, _.dir)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref271) {
  var similar = _ref271.similar,
      end = _ref271.end;

  similar((0, _.dir)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref272) {
  var similar = _ref272.similar,
      end = _ref272.end;

  similar((0, _.dir)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref273) {
  var similar = _ref273.similar,
      end = _ref273.end;

  similar((0, _.dir)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "dir#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref274) {
  var equal = _ref274.equal,
      end = _ref274.end;

  equal((0, _snabbdomToHtml2.default)((0, _.dir)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dir id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</dir>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref275) {
  var equal = _ref275.equal,
      end = _ref275.end;

  equal(toHTMLWithPlugins((0, _.dir)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dir id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</dir>");
  end();
});

(0, _tap.test)("empty", function (_ref276) {
  var similar = _ref276.similar,
      end = _ref276.end;

  similar((0, _.div)(), { sel: "div" });
  end();
});

(0, _tap.test)("selector", function (_ref277) {
  var similar = _ref277.similar,
      end = _ref277.end;

  similar((0, _.div)({ selector: ".value" }), { sel: "div.value" });
  end();
});

(0, _tap.test)("children string", function (_ref278) {
  var similar = _ref278.similar,
      end = _ref278.end;

  similar((0, _.div)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref279) {
  var similar = _ref279.similar,
      end = _ref279.end;

  similar((0, _.div)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref280) {
  var similar = _ref280.similar,
      end = _ref280.end;

  similar((0, _.div)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref281) {
  var similar = _ref281.similar,
      end = _ref281.end;

  similar((0, _.div)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref282) {
  var similar = _ref282.similar,
      end = _ref282.end;

  similar((0, _.div)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref283) {
  var similar = _ref283.similar,
      end = _ref283.end;

  similar((0, _.div)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref284) {
  var similar = _ref284.similar,
      end = _ref284.end;

  similar((0, _.div)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "div#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref285) {
  var equal = _ref285.equal,
      end = _ref285.end;

  equal((0, _snabbdomToHtml2.default)((0, _.div)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<div id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</div>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref286) {
  var equal = _ref286.equal,
      end = _ref286.end;

  equal(toHTMLWithPlugins((0, _.div)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<div id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</div>");
  end();
});

(0, _tap.test)("empty", function (_ref287) {
  var similar = _ref287.similar,
      end = _ref287.end;

  similar((0, _.dl)(), { sel: "dl" });
  end();
});

(0, _tap.test)("selector", function (_ref288) {
  var similar = _ref288.similar,
      end = _ref288.end;

  similar((0, _.dl)({ selector: ".value" }), { sel: "dl.value" });
  end();
});

(0, _tap.test)("children string", function (_ref289) {
  var similar = _ref289.similar,
      end = _ref289.end;

  similar((0, _.dl)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref290) {
  var similar = _ref290.similar,
      end = _ref290.end;

  similar((0, _.dl)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref291) {
  var similar = _ref291.similar,
      end = _ref291.end;

  similar((0, _.dl)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref292) {
  var similar = _ref292.similar,
      end = _ref292.end;

  similar((0, _.dl)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref293) {
  var similar = _ref293.similar,
      end = _ref293.end;

  similar((0, _.dl)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref294) {
  var similar = _ref294.similar,
      end = _ref294.end;

  similar((0, _.dl)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref295) {
  var similar = _ref295.similar,
      end = _ref295.end;

  similar((0, _.dl)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "dl#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref296) {
  var equal = _ref296.equal,
      end = _ref296.end;

  equal((0, _snabbdomToHtml2.default)((0, _.dl)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dl id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</dl>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref297) {
  var equal = _ref297.equal,
      end = _ref297.end;

  equal(toHTMLWithPlugins((0, _.dl)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dl id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</dl>");
  end();
});

(0, _tap.test)("empty", function (_ref298) {
  var similar = _ref298.similar,
      end = _ref298.end;

  similar((0, _.dt)(), { sel: "dt" });
  end();
});

(0, _tap.test)("selector", function (_ref299) {
  var similar = _ref299.similar,
      end = _ref299.end;

  similar((0, _.dt)({ selector: ".value" }), { sel: "dt.value" });
  end();
});

(0, _tap.test)("children string", function (_ref300) {
  var similar = _ref300.similar,
      end = _ref300.end;

  similar((0, _.dt)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref301) {
  var similar = _ref301.similar,
      end = _ref301.end;

  similar((0, _.dt)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref302) {
  var similar = _ref302.similar,
      end = _ref302.end;

  similar((0, _.dt)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref303) {
  var similar = _ref303.similar,
      end = _ref303.end;

  similar((0, _.dt)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref304) {
  var similar = _ref304.similar,
      end = _ref304.end;

  similar((0, _.dt)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref305) {
  var similar = _ref305.similar,
      end = _ref305.end;

  similar((0, _.dt)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref306) {
  var similar = _ref306.similar,
      end = _ref306.end;

  similar((0, _.dt)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "dt#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref307) {
  var equal = _ref307.equal,
      end = _ref307.end;

  equal((0, _snabbdomToHtml2.default)((0, _.dt)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dt id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</dt>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref308) {
  var equal = _ref308.equal,
      end = _ref308.end;

  equal(toHTMLWithPlugins((0, _.dt)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<dt id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</dt>");
  end();
});

(0, _tap.test)("empty", function (_ref309) {
  var similar = _ref309.similar,
      end = _ref309.end;

  similar((0, _.em)(), { sel: "em" });
  end();
});

(0, _tap.test)("selector", function (_ref310) {
  var similar = _ref310.similar,
      end = _ref310.end;

  similar((0, _.em)({ selector: ".value" }), { sel: "em.value" });
  end();
});

(0, _tap.test)("children string", function (_ref311) {
  var similar = _ref311.similar,
      end = _ref311.end;

  similar((0, _.em)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref312) {
  var similar = _ref312.similar,
      end = _ref312.end;

  similar((0, _.em)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref313) {
  var similar = _ref313.similar,
      end = _ref313.end;

  similar((0, _.em)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref314) {
  var similar = _ref314.similar,
      end = _ref314.end;

  similar((0, _.em)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref315) {
  var similar = _ref315.similar,
      end = _ref315.end;

  similar((0, _.em)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref316) {
  var similar = _ref316.similar,
      end = _ref316.end;

  similar((0, _.em)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref317) {
  var similar = _ref317.similar,
      end = _ref317.end;

  similar((0, _.em)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "em#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref318) {
  var equal = _ref318.equal,
      end = _ref318.end;

  equal((0, _snabbdomToHtml2.default)((0, _.em)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<em id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</em>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref319) {
  var equal = _ref319.equal,
      end = _ref319.end;

  equal(toHTMLWithPlugins((0, _.em)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<em id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</em>");
  end();
});

(0, _tap.test)("empty", function (_ref320) {
  var similar = _ref320.similar,
      end = _ref320.end;

  similar((0, _.fieldset)(), { sel: "fieldset" });
  end();
});

(0, _tap.test)("selector", function (_ref321) {
  var similar = _ref321.similar,
      end = _ref321.end;

  similar((0, _.fieldset)({ selector: ".value" }), { sel: "fieldset.value" });
  end();
});

(0, _tap.test)("children string", function (_ref322) {
  var similar = _ref322.similar,
      end = _ref322.end;

  similar((0, _.fieldset)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref323) {
  var similar = _ref323.similar,
      end = _ref323.end;

  similar((0, _.fieldset)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref324) {
  var similar = _ref324.similar,
      end = _ref324.end;

  similar((0, _.fieldset)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref325) {
  var similar = _ref325.similar,
      end = _ref325.end;

  similar((0, _.fieldset)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref326) {
  var similar = _ref326.similar,
      end = _ref326.end;

  similar((0, _.fieldset)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref327) {
  var similar = _ref327.similar,
      end = _ref327.end;

  similar((0, _.fieldset)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref328) {
  var similar = _ref328.similar,
      end = _ref328.end;

  similar((0, _.fieldset)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "fieldset#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref329) {
  var equal = _ref329.equal,
      end = _ref329.end;

  equal((0, _snabbdomToHtml2.default)((0, _.fieldset)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<fieldset id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</fieldset>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref330) {
  var equal = _ref330.equal,
      end = _ref330.end;

  equal(toHTMLWithPlugins((0, _.fieldset)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<fieldset id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</fieldset>");
  end();
});

(0, _tap.test)("empty", function (_ref331) {
  var similar = _ref331.similar,
      end = _ref331.end;

  similar((0, _.figcaption)(), { sel: "figcaption" });
  end();
});

(0, _tap.test)("selector", function (_ref332) {
  var similar = _ref332.similar,
      end = _ref332.end;

  similar((0, _.figcaption)({ selector: ".value" }), { sel: "figcaption.value" });
  end();
});

(0, _tap.test)("children string", function (_ref333) {
  var similar = _ref333.similar,
      end = _ref333.end;

  similar((0, _.figcaption)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref334) {
  var similar = _ref334.similar,
      end = _ref334.end;

  similar((0, _.figcaption)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref335) {
  var similar = _ref335.similar,
      end = _ref335.end;

  similar((0, _.figcaption)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref336) {
  var similar = _ref336.similar,
      end = _ref336.end;

  similar((0, _.figcaption)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref337) {
  var similar = _ref337.similar,
      end = _ref337.end;

  similar((0, _.figcaption)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref338) {
  var similar = _ref338.similar,
      end = _ref338.end;

  similar((0, _.figcaption)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref339) {
  var similar = _ref339.similar,
      end = _ref339.end;

  similar((0, _.figcaption)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "figcaption#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref340) {
  var equal = _ref340.equal,
      end = _ref340.end;

  equal((0, _snabbdomToHtml2.default)((0, _.figcaption)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<figcaption id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</figcaption>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref341) {
  var equal = _ref341.equal,
      end = _ref341.end;

  equal(toHTMLWithPlugins((0, _.figcaption)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<figcaption id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</figcaption>");
  end();
});

(0, _tap.test)("empty", function (_ref342) {
  var similar = _ref342.similar,
      end = _ref342.end;

  similar((0, _.figure)(), { sel: "figure" });
  end();
});

(0, _tap.test)("selector", function (_ref343) {
  var similar = _ref343.similar,
      end = _ref343.end;

  similar((0, _.figure)({ selector: ".value" }), { sel: "figure.value" });
  end();
});

(0, _tap.test)("children string", function (_ref344) {
  var similar = _ref344.similar,
      end = _ref344.end;

  similar((0, _.figure)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref345) {
  var similar = _ref345.similar,
      end = _ref345.end;

  similar((0, _.figure)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref346) {
  var similar = _ref346.similar,
      end = _ref346.end;

  similar((0, _.figure)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref347) {
  var similar = _ref347.similar,
      end = _ref347.end;

  similar((0, _.figure)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref348) {
  var similar = _ref348.similar,
      end = _ref348.end;

  similar((0, _.figure)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref349) {
  var similar = _ref349.similar,
      end = _ref349.end;

  similar((0, _.figure)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref350) {
  var similar = _ref350.similar,
      end = _ref350.end;

  similar((0, _.figure)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "figure#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref351) {
  var equal = _ref351.equal,
      end = _ref351.end;

  equal((0, _snabbdomToHtml2.default)((0, _.figure)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<figure id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</figure>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref352) {
  var equal = _ref352.equal,
      end = _ref352.end;

  equal(toHTMLWithPlugins((0, _.figure)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<figure id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</figure>");
  end();
});

(0, _tap.test)("empty", function (_ref353) {
  var similar = _ref353.similar,
      end = _ref353.end;

  similar((0, _.footer)(), { sel: "footer" });
  end();
});

(0, _tap.test)("selector", function (_ref354) {
  var similar = _ref354.similar,
      end = _ref354.end;

  similar((0, _.footer)({ selector: ".value" }), { sel: "footer.value" });
  end();
});

(0, _tap.test)("children string", function (_ref355) {
  var similar = _ref355.similar,
      end = _ref355.end;

  similar((0, _.footer)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref356) {
  var similar = _ref356.similar,
      end = _ref356.end;

  similar((0, _.footer)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref357) {
  var similar = _ref357.similar,
      end = _ref357.end;

  similar((0, _.footer)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref358) {
  var similar = _ref358.similar,
      end = _ref358.end;

  similar((0, _.footer)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref359) {
  var similar = _ref359.similar,
      end = _ref359.end;

  similar((0, _.footer)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref360) {
  var similar = _ref360.similar,
      end = _ref360.end;

  similar((0, _.footer)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref361) {
  var similar = _ref361.similar,
      end = _ref361.end;

  similar((0, _.footer)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "footer#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref362) {
  var equal = _ref362.equal,
      end = _ref362.end;

  equal((0, _snabbdomToHtml2.default)((0, _.footer)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<footer id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</footer>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref363) {
  var equal = _ref363.equal,
      end = _ref363.end;

  equal(toHTMLWithPlugins((0, _.footer)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<footer id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</footer>");
  end();
});

(0, _tap.test)("empty", function (_ref364) {
  var similar = _ref364.similar,
      end = _ref364.end;

  similar((0, _.form)(), { sel: "form" });
  end();
});

(0, _tap.test)("selector", function (_ref365) {
  var similar = _ref365.similar,
      end = _ref365.end;

  similar((0, _.form)({ selector: ".value" }), { sel: "form.value" });
  end();
});

(0, _tap.test)("children string", function (_ref366) {
  var similar = _ref366.similar,
      end = _ref366.end;

  similar((0, _.form)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref367) {
  var similar = _ref367.similar,
      end = _ref367.end;

  similar((0, _.form)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref368) {
  var similar = _ref368.similar,
      end = _ref368.end;

  similar((0, _.form)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref369) {
  var similar = _ref369.similar,
      end = _ref369.end;

  similar((0, _.form)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref370) {
  var similar = _ref370.similar,
      end = _ref370.end;

  similar((0, _.form)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref371) {
  var similar = _ref371.similar,
      end = _ref371.end;

  similar((0, _.form)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref372) {
  var similar = _ref372.similar,
      end = _ref372.end;

  similar((0, _.form)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "form#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref373) {
  var equal = _ref373.equal,
      end = _ref373.end;

  equal((0, _snabbdomToHtml2.default)((0, _.form)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<form id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</form>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref374) {
  var equal = _ref374.equal,
      end = _ref374.end;

  equal(toHTMLWithPlugins((0, _.form)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<form id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</form>");
  end();
});

(0, _tap.test)("empty", function (_ref375) {
  var similar = _ref375.similar,
      end = _ref375.end;

  similar((0, _.h1)(), { sel: "h1" });
  end();
});

(0, _tap.test)("selector", function (_ref376) {
  var similar = _ref376.similar,
      end = _ref376.end;

  similar((0, _.h1)({ selector: ".value" }), { sel: "h1.value" });
  end();
});

(0, _tap.test)("children string", function (_ref377) {
  var similar = _ref377.similar,
      end = _ref377.end;

  similar((0, _.h1)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref378) {
  var similar = _ref378.similar,
      end = _ref378.end;

  similar((0, _.h1)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref379) {
  var similar = _ref379.similar,
      end = _ref379.end;

  similar((0, _.h1)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref380) {
  var similar = _ref380.similar,
      end = _ref380.end;

  similar((0, _.h1)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref381) {
  var similar = _ref381.similar,
      end = _ref381.end;

  similar((0, _.h1)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref382) {
  var similar = _ref382.similar,
      end = _ref382.end;

  similar((0, _.h1)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref383) {
  var similar = _ref383.similar,
      end = _ref383.end;

  similar((0, _.h1)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "h1#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref384) {
  var equal = _ref384.equal,
      end = _ref384.end;

  equal((0, _snabbdomToHtml2.default)((0, _.h1)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h1 id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</h1>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref385) {
  var equal = _ref385.equal,
      end = _ref385.end;

  equal(toHTMLWithPlugins((0, _.h1)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h1 id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</h1>");
  end();
});

(0, _tap.test)("empty", function (_ref386) {
  var similar = _ref386.similar,
      end = _ref386.end;

  similar((0, _.h2)(), { sel: "h2" });
  end();
});

(0, _tap.test)("selector", function (_ref387) {
  var similar = _ref387.similar,
      end = _ref387.end;

  similar((0, _.h2)({ selector: ".value" }), { sel: "h2.value" });
  end();
});

(0, _tap.test)("children string", function (_ref388) {
  var similar = _ref388.similar,
      end = _ref388.end;

  similar((0, _.h2)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref389) {
  var similar = _ref389.similar,
      end = _ref389.end;

  similar((0, _.h2)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref390) {
  var similar = _ref390.similar,
      end = _ref390.end;

  similar((0, _.h2)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref391) {
  var similar = _ref391.similar,
      end = _ref391.end;

  similar((0, _.h2)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref392) {
  var similar = _ref392.similar,
      end = _ref392.end;

  similar((0, _.h2)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref393) {
  var similar = _ref393.similar,
      end = _ref393.end;

  similar((0, _.h2)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref394) {
  var similar = _ref394.similar,
      end = _ref394.end;

  similar((0, _.h2)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "h2#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref395) {
  var equal = _ref395.equal,
      end = _ref395.end;

  equal((0, _snabbdomToHtml2.default)((0, _.h2)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h2 id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</h2>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref396) {
  var equal = _ref396.equal,
      end = _ref396.end;

  equal(toHTMLWithPlugins((0, _.h2)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h2 id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</h2>");
  end();
});

(0, _tap.test)("empty", function (_ref397) {
  var similar = _ref397.similar,
      end = _ref397.end;

  similar((0, _.h3)(), { sel: "h3" });
  end();
});

(0, _tap.test)("selector", function (_ref398) {
  var similar = _ref398.similar,
      end = _ref398.end;

  similar((0, _.h3)({ selector: ".value" }), { sel: "h3.value" });
  end();
});

(0, _tap.test)("children string", function (_ref399) {
  var similar = _ref399.similar,
      end = _ref399.end;

  similar((0, _.h3)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref400) {
  var similar = _ref400.similar,
      end = _ref400.end;

  similar((0, _.h3)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref401) {
  var similar = _ref401.similar,
      end = _ref401.end;

  similar((0, _.h3)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref402) {
  var similar = _ref402.similar,
      end = _ref402.end;

  similar((0, _.h3)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref403) {
  var similar = _ref403.similar,
      end = _ref403.end;

  similar((0, _.h3)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref404) {
  var similar = _ref404.similar,
      end = _ref404.end;

  similar((0, _.h3)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref405) {
  var similar = _ref405.similar,
      end = _ref405.end;

  similar((0, _.h3)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "h3#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref406) {
  var equal = _ref406.equal,
      end = _ref406.end;

  equal((0, _snabbdomToHtml2.default)((0, _.h3)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h3 id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</h3>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref407) {
  var equal = _ref407.equal,
      end = _ref407.end;

  equal(toHTMLWithPlugins((0, _.h3)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h3 id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</h3>");
  end();
});

(0, _tap.test)("empty", function (_ref408) {
  var similar = _ref408.similar,
      end = _ref408.end;

  similar((0, _.h4)(), { sel: "h4" });
  end();
});

(0, _tap.test)("selector", function (_ref409) {
  var similar = _ref409.similar,
      end = _ref409.end;

  similar((0, _.h4)({ selector: ".value" }), { sel: "h4.value" });
  end();
});

(0, _tap.test)("children string", function (_ref410) {
  var similar = _ref410.similar,
      end = _ref410.end;

  similar((0, _.h4)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref411) {
  var similar = _ref411.similar,
      end = _ref411.end;

  similar((0, _.h4)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref412) {
  var similar = _ref412.similar,
      end = _ref412.end;

  similar((0, _.h4)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref413) {
  var similar = _ref413.similar,
      end = _ref413.end;

  similar((0, _.h4)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref414) {
  var similar = _ref414.similar,
      end = _ref414.end;

  similar((0, _.h4)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref415) {
  var similar = _ref415.similar,
      end = _ref415.end;

  similar((0, _.h4)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref416) {
  var similar = _ref416.similar,
      end = _ref416.end;

  similar((0, _.h4)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "h4#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref417) {
  var equal = _ref417.equal,
      end = _ref417.end;

  equal((0, _snabbdomToHtml2.default)((0, _.h4)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h4 id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</h4>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref418) {
  var equal = _ref418.equal,
      end = _ref418.end;

  equal(toHTMLWithPlugins((0, _.h4)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h4 id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</h4>");
  end();
});

(0, _tap.test)("empty", function (_ref419) {
  var similar = _ref419.similar,
      end = _ref419.end;

  similar((0, _.h5)(), { sel: "h5" });
  end();
});

(0, _tap.test)("selector", function (_ref420) {
  var similar = _ref420.similar,
      end = _ref420.end;

  similar((0, _.h5)({ selector: ".value" }), { sel: "h5.value" });
  end();
});

(0, _tap.test)("children string", function (_ref421) {
  var similar = _ref421.similar,
      end = _ref421.end;

  similar((0, _.h5)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref422) {
  var similar = _ref422.similar,
      end = _ref422.end;

  similar((0, _.h5)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref423) {
  var similar = _ref423.similar,
      end = _ref423.end;

  similar((0, _.h5)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref424) {
  var similar = _ref424.similar,
      end = _ref424.end;

  similar((0, _.h5)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref425) {
  var similar = _ref425.similar,
      end = _ref425.end;

  similar((0, _.h5)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref426) {
  var similar = _ref426.similar,
      end = _ref426.end;

  similar((0, _.h5)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref427) {
  var similar = _ref427.similar,
      end = _ref427.end;

  similar((0, _.h5)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "h5#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref428) {
  var equal = _ref428.equal,
      end = _ref428.end;

  equal((0, _snabbdomToHtml2.default)((0, _.h5)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h5 id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</h5>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref429) {
  var equal = _ref429.equal,
      end = _ref429.end;

  equal(toHTMLWithPlugins((0, _.h5)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h5 id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</h5>");
  end();
});

(0, _tap.test)("empty", function (_ref430) {
  var similar = _ref430.similar,
      end = _ref430.end;

  similar((0, _.h6)(), { sel: "h6" });
  end();
});

(0, _tap.test)("selector", function (_ref431) {
  var similar = _ref431.similar,
      end = _ref431.end;

  similar((0, _.h6)({ selector: ".value" }), { sel: "h6.value" });
  end();
});

(0, _tap.test)("children string", function (_ref432) {
  var similar = _ref432.similar,
      end = _ref432.end;

  similar((0, _.h6)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref433) {
  var similar = _ref433.similar,
      end = _ref433.end;

  similar((0, _.h6)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref434) {
  var similar = _ref434.similar,
      end = _ref434.end;

  similar((0, _.h6)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref435) {
  var similar = _ref435.similar,
      end = _ref435.end;

  similar((0, _.h6)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref436) {
  var similar = _ref436.similar,
      end = _ref436.end;

  similar((0, _.h6)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref437) {
  var similar = _ref437.similar,
      end = _ref437.end;

  similar((0, _.h6)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref438) {
  var similar = _ref438.similar,
      end = _ref438.end;

  similar((0, _.h6)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "h6#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref439) {
  var equal = _ref439.equal,
      end = _ref439.end;

  equal((0, _snabbdomToHtml2.default)((0, _.h6)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h6 id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</h6>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref440) {
  var equal = _ref440.equal,
      end = _ref440.end;

  equal(toHTMLWithPlugins((0, _.h6)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<h6 id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</h6>");
  end();
});

(0, _tap.test)("empty", function (_ref441) {
  var similar = _ref441.similar,
      end = _ref441.end;

  similar((0, _.head)(), { sel: "head" });
  end();
});

(0, _tap.test)("selector", function (_ref442) {
  var similar = _ref442.similar,
      end = _ref442.end;

  similar((0, _.head)({ selector: ".value" }), { sel: "head.value" });
  end();
});

(0, _tap.test)("children string", function (_ref443) {
  var similar = _ref443.similar,
      end = _ref443.end;

  similar((0, _.head)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref444) {
  var similar = _ref444.similar,
      end = _ref444.end;

  similar((0, _.head)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref445) {
  var similar = _ref445.similar,
      end = _ref445.end;

  similar((0, _.head)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref446) {
  var similar = _ref446.similar,
      end = _ref446.end;

  similar((0, _.head)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref447) {
  var similar = _ref447.similar,
      end = _ref447.end;

  similar((0, _.head)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref448) {
  var similar = _ref448.similar,
      end = _ref448.end;

  similar((0, _.head)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref449) {
  var similar = _ref449.similar,
      end = _ref449.end;

  similar((0, _.head)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "head#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref450) {
  var equal = _ref450.equal,
      end = _ref450.end;

  equal((0, _snabbdomToHtml2.default)((0, _.head)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<head id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</head>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref451) {
  var equal = _ref451.equal,
      end = _ref451.end;

  equal(toHTMLWithPlugins((0, _.head)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<head id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</head>");
  end();
});

(0, _tap.test)("empty", function (_ref452) {
  var similar = _ref452.similar,
      end = _ref452.end;

  similar((0, _.header)(), { sel: "header" });
  end();
});

(0, _tap.test)("selector", function (_ref453) {
  var similar = _ref453.similar,
      end = _ref453.end;

  similar((0, _.header)({ selector: ".value" }), { sel: "header.value" });
  end();
});

(0, _tap.test)("children string", function (_ref454) {
  var similar = _ref454.similar,
      end = _ref454.end;

  similar((0, _.header)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref455) {
  var similar = _ref455.similar,
      end = _ref455.end;

  similar((0, _.header)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref456) {
  var similar = _ref456.similar,
      end = _ref456.end;

  similar((0, _.header)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref457) {
  var similar = _ref457.similar,
      end = _ref457.end;

  similar((0, _.header)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref458) {
  var similar = _ref458.similar,
      end = _ref458.end;

  similar((0, _.header)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref459) {
  var similar = _ref459.similar,
      end = _ref459.end;

  similar((0, _.header)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref460) {
  var similar = _ref460.similar,
      end = _ref460.end;

  similar((0, _.header)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "header#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref461) {
  var equal = _ref461.equal,
      end = _ref461.end;

  equal((0, _snabbdomToHtml2.default)((0, _.header)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<header id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</header>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref462) {
  var equal = _ref462.equal,
      end = _ref462.end;

  equal(toHTMLWithPlugins((0, _.header)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<header id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</header>");
  end();
});

(0, _tap.test)("empty", function (_ref463) {
  var similar = _ref463.similar,
      end = _ref463.end;

  similar((0, _.hgroup)(), { sel: "hgroup" });
  end();
});

(0, _tap.test)("selector", function (_ref464) {
  var similar = _ref464.similar,
      end = _ref464.end;

  similar((0, _.hgroup)({ selector: ".value" }), { sel: "hgroup.value" });
  end();
});

(0, _tap.test)("children string", function (_ref465) {
  var similar = _ref465.similar,
      end = _ref465.end;

  similar((0, _.hgroup)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref466) {
  var similar = _ref466.similar,
      end = _ref466.end;

  similar((0, _.hgroup)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref467) {
  var similar = _ref467.similar,
      end = _ref467.end;

  similar((0, _.hgroup)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref468) {
  var similar = _ref468.similar,
      end = _ref468.end;

  similar((0, _.hgroup)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref469) {
  var similar = _ref469.similar,
      end = _ref469.end;

  similar((0, _.hgroup)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref470) {
  var similar = _ref470.similar,
      end = _ref470.end;

  similar((0, _.hgroup)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref471) {
  var similar = _ref471.similar,
      end = _ref471.end;

  similar((0, _.hgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "hgroup#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref472) {
  var equal = _ref472.equal,
      end = _ref472.end;

  equal((0, _snabbdomToHtml2.default)((0, _.hgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<hgroup id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</hgroup>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref473) {
  var equal = _ref473.equal,
      end = _ref473.end;

  equal(toHTMLWithPlugins((0, _.hgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<hgroup id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</hgroup>");
  end();
});

(0, _tap.test)("empty", function (_ref474) {
  var similar = _ref474.similar,
      end = _ref474.end;

  similar((0, _.html)(), { sel: "html" });
  end();
});

(0, _tap.test)("selector", function (_ref475) {
  var similar = _ref475.similar,
      end = _ref475.end;

  similar((0, _.html)({ selector: ".value" }), { sel: "html.value" });
  end();
});

(0, _tap.test)("children string", function (_ref476) {
  var similar = _ref476.similar,
      end = _ref476.end;

  similar((0, _.html)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref477) {
  var similar = _ref477.similar,
      end = _ref477.end;

  similar((0, _.html)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref478) {
  var similar = _ref478.similar,
      end = _ref478.end;

  similar((0, _.html)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref479) {
  var similar = _ref479.similar,
      end = _ref479.end;

  similar((0, _.html)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref480) {
  var similar = _ref480.similar,
      end = _ref480.end;

  similar((0, _.html)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref481) {
  var similar = _ref481.similar,
      end = _ref481.end;

  similar((0, _.html)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref482) {
  var similar = _ref482.similar,
      end = _ref482.end;

  similar((0, _.html)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "html#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref483) {
  var equal = _ref483.equal,
      end = _ref483.end;

  equal((0, _snabbdomToHtml2.default)((0, _.html)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<html id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</html>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref484) {
  var equal = _ref484.equal,
      end = _ref484.end;

  equal(toHTMLWithPlugins((0, _.html)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<html id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</html>");
  end();
});

(0, _tap.test)("empty", function (_ref485) {
  var similar = _ref485.similar,
      end = _ref485.end;

  similar((0, _.i)(), { sel: "i" });
  end();
});

(0, _tap.test)("selector", function (_ref486) {
  var similar = _ref486.similar,
      end = _ref486.end;

  similar((0, _.i)({ selector: ".value" }), { sel: "i.value" });
  end();
});

(0, _tap.test)("children string", function (_ref487) {
  var similar = _ref487.similar,
      end = _ref487.end;

  similar((0, _.i)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref488) {
  var similar = _ref488.similar,
      end = _ref488.end;

  similar((0, _.i)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref489) {
  var similar = _ref489.similar,
      end = _ref489.end;

  similar((0, _.i)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref490) {
  var similar = _ref490.similar,
      end = _ref490.end;

  similar((0, _.i)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref491) {
  var similar = _ref491.similar,
      end = _ref491.end;

  similar((0, _.i)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref492) {
  var similar = _ref492.similar,
      end = _ref492.end;

  similar((0, _.i)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref493) {
  var similar = _ref493.similar,
      end = _ref493.end;

  similar((0, _.i)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "i#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref494) {
  var equal = _ref494.equal,
      end = _ref494.end;

  equal((0, _snabbdomToHtml2.default)((0, _.i)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<i id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</i>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref495) {
  var equal = _ref495.equal,
      end = _ref495.end;

  equal(toHTMLWithPlugins((0, _.i)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<i id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</i>");
  end();
});

(0, _tap.test)("empty", function (_ref496) {
  var similar = _ref496.similar,
      end = _ref496.end;

  similar((0, _.iframe)(), { sel: "iframe" });
  end();
});

(0, _tap.test)("selector", function (_ref497) {
  var similar = _ref497.similar,
      end = _ref497.end;

  similar((0, _.iframe)({ selector: ".value" }), { sel: "iframe.value" });
  end();
});

(0, _tap.test)("children string", function (_ref498) {
  var similar = _ref498.similar,
      end = _ref498.end;

  similar((0, _.iframe)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref499) {
  var similar = _ref499.similar,
      end = _ref499.end;

  similar((0, _.iframe)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref500) {
  var similar = _ref500.similar,
      end = _ref500.end;

  similar((0, _.iframe)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref501) {
  var similar = _ref501.similar,
      end = _ref501.end;

  similar((0, _.iframe)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref502) {
  var similar = _ref502.similar,
      end = _ref502.end;

  similar((0, _.iframe)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref503) {
  var similar = _ref503.similar,
      end = _ref503.end;

  similar((0, _.iframe)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref504) {
  var similar = _ref504.similar,
      end = _ref504.end;

  similar((0, _.iframe)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "iframe#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref505) {
  var equal = _ref505.equal,
      end = _ref505.end;

  equal((0, _snabbdomToHtml2.default)((0, _.iframe)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<iframe id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</iframe>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref506) {
  var equal = _ref506.equal,
      end = _ref506.end;

  equal(toHTMLWithPlugins((0, _.iframe)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<iframe id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</iframe>");
  end();
});

(0, _tap.test)("empty", function (_ref507) {
  var similar = _ref507.similar,
      end = _ref507.end;

  similar((0, _.ins)(), { sel: "ins" });
  end();
});

(0, _tap.test)("selector", function (_ref508) {
  var similar = _ref508.similar,
      end = _ref508.end;

  similar((0, _.ins)({ selector: ".value" }), { sel: "ins.value" });
  end();
});

(0, _tap.test)("children string", function (_ref509) {
  var similar = _ref509.similar,
      end = _ref509.end;

  similar((0, _.ins)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref510) {
  var similar = _ref510.similar,
      end = _ref510.end;

  similar((0, _.ins)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref511) {
  var similar = _ref511.similar,
      end = _ref511.end;

  similar((0, _.ins)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref512) {
  var similar = _ref512.similar,
      end = _ref512.end;

  similar((0, _.ins)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref513) {
  var similar = _ref513.similar,
      end = _ref513.end;

  similar((0, _.ins)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref514) {
  var similar = _ref514.similar,
      end = _ref514.end;

  similar((0, _.ins)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref515) {
  var similar = _ref515.similar,
      end = _ref515.end;

  similar((0, _.ins)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "ins#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref516) {
  var equal = _ref516.equal,
      end = _ref516.end;

  equal((0, _snabbdomToHtml2.default)((0, _.ins)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ins id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</ins>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref517) {
  var equal = _ref517.equal,
      end = _ref517.end;

  equal(toHTMLWithPlugins((0, _.ins)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ins id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</ins>");
  end();
});

(0, _tap.test)("empty", function (_ref518) {
  var similar = _ref518.similar,
      end = _ref518.end;

  similar((0, _.kbd)(), { sel: "kbd" });
  end();
});

(0, _tap.test)("selector", function (_ref519) {
  var similar = _ref519.similar,
      end = _ref519.end;

  similar((0, _.kbd)({ selector: ".value" }), { sel: "kbd.value" });
  end();
});

(0, _tap.test)("children string", function (_ref520) {
  var similar = _ref520.similar,
      end = _ref520.end;

  similar((0, _.kbd)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref521) {
  var similar = _ref521.similar,
      end = _ref521.end;

  similar((0, _.kbd)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref522) {
  var similar = _ref522.similar,
      end = _ref522.end;

  similar((0, _.kbd)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref523) {
  var similar = _ref523.similar,
      end = _ref523.end;

  similar((0, _.kbd)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref524) {
  var similar = _ref524.similar,
      end = _ref524.end;

  similar((0, _.kbd)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref525) {
  var similar = _ref525.similar,
      end = _ref525.end;

  similar((0, _.kbd)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref526) {
  var similar = _ref526.similar,
      end = _ref526.end;

  similar((0, _.kbd)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "kbd#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref527) {
  var equal = _ref527.equal,
      end = _ref527.end;

  equal((0, _snabbdomToHtml2.default)((0, _.kbd)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<kbd id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</kbd>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref528) {
  var equal = _ref528.equal,
      end = _ref528.end;

  equal(toHTMLWithPlugins((0, _.kbd)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<kbd id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</kbd>");
  end();
});

(0, _tap.test)("empty", function (_ref529) {
  var similar = _ref529.similar,
      end = _ref529.end;

  similar((0, _.label)(), { sel: "label" });
  end();
});

(0, _tap.test)("selector", function (_ref530) {
  var similar = _ref530.similar,
      end = _ref530.end;

  similar((0, _.label)({ selector: ".value" }), { sel: "label.value" });
  end();
});

(0, _tap.test)("children string", function (_ref531) {
  var similar = _ref531.similar,
      end = _ref531.end;

  similar((0, _.label)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref532) {
  var similar = _ref532.similar,
      end = _ref532.end;

  similar((0, _.label)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref533) {
  var similar = _ref533.similar,
      end = _ref533.end;

  similar((0, _.label)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref534) {
  var similar = _ref534.similar,
      end = _ref534.end;

  similar((0, _.label)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref535) {
  var similar = _ref535.similar,
      end = _ref535.end;

  similar((0, _.label)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref536) {
  var similar = _ref536.similar,
      end = _ref536.end;

  similar((0, _.label)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref537) {
  var similar = _ref537.similar,
      end = _ref537.end;

  similar((0, _.label)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "label#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref538) {
  var equal = _ref538.equal,
      end = _ref538.end;

  equal((0, _snabbdomToHtml2.default)((0, _.label)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<label id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</label>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref539) {
  var equal = _ref539.equal,
      end = _ref539.end;

  equal(toHTMLWithPlugins((0, _.label)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<label id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</label>");
  end();
});

(0, _tap.test)("empty", function (_ref540) {
  var similar = _ref540.similar,
      end = _ref540.end;

  similar((0, _.legend)(), { sel: "legend" });
  end();
});

(0, _tap.test)("selector", function (_ref541) {
  var similar = _ref541.similar,
      end = _ref541.end;

  similar((0, _.legend)({ selector: ".value" }), { sel: "legend.value" });
  end();
});

(0, _tap.test)("children string", function (_ref542) {
  var similar = _ref542.similar,
      end = _ref542.end;

  similar((0, _.legend)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref543) {
  var similar = _ref543.similar,
      end = _ref543.end;

  similar((0, _.legend)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref544) {
  var similar = _ref544.similar,
      end = _ref544.end;

  similar((0, _.legend)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref545) {
  var similar = _ref545.similar,
      end = _ref545.end;

  similar((0, _.legend)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref546) {
  var similar = _ref546.similar,
      end = _ref546.end;

  similar((0, _.legend)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref547) {
  var similar = _ref547.similar,
      end = _ref547.end;

  similar((0, _.legend)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref548) {
  var similar = _ref548.similar,
      end = _ref548.end;

  similar((0, _.legend)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "legend#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref549) {
  var equal = _ref549.equal,
      end = _ref549.end;

  equal((0, _snabbdomToHtml2.default)((0, _.legend)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<legend id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</legend>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref550) {
  var equal = _ref550.equal,
      end = _ref550.end;

  equal(toHTMLWithPlugins((0, _.legend)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<legend id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</legend>");
  end();
});

(0, _tap.test)("empty", function (_ref551) {
  var similar = _ref551.similar,
      end = _ref551.end;

  similar((0, _.li)(), { sel: "li" });
  end();
});

(0, _tap.test)("selector", function (_ref552) {
  var similar = _ref552.similar,
      end = _ref552.end;

  similar((0, _.li)({ selector: ".value" }), { sel: "li.value" });
  end();
});

(0, _tap.test)("children string", function (_ref553) {
  var similar = _ref553.similar,
      end = _ref553.end;

  similar((0, _.li)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref554) {
  var similar = _ref554.similar,
      end = _ref554.end;

  similar((0, _.li)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref555) {
  var similar = _ref555.similar,
      end = _ref555.end;

  similar((0, _.li)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref556) {
  var similar = _ref556.similar,
      end = _ref556.end;

  similar((0, _.li)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref557) {
  var similar = _ref557.similar,
      end = _ref557.end;

  similar((0, _.li)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref558) {
  var similar = _ref558.similar,
      end = _ref558.end;

  similar((0, _.li)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref559) {
  var similar = _ref559.similar,
      end = _ref559.end;

  similar((0, _.li)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "li#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref560) {
  var equal = _ref560.equal,
      end = _ref560.end;

  equal((0, _snabbdomToHtml2.default)((0, _.li)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<li id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</li>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref561) {
  var equal = _ref561.equal,
      end = _ref561.end;

  equal(toHTMLWithPlugins((0, _.li)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<li id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</li>");
  end();
});

(0, _tap.test)("empty", function (_ref562) {
  var similar = _ref562.similar,
      end = _ref562.end;

  similar((0, _.main)(), { sel: "main" });
  end();
});

(0, _tap.test)("selector", function (_ref563) {
  var similar = _ref563.similar,
      end = _ref563.end;

  similar((0, _.main)({ selector: ".value" }), { sel: "main.value" });
  end();
});

(0, _tap.test)("children string", function (_ref564) {
  var similar = _ref564.similar,
      end = _ref564.end;

  similar((0, _.main)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref565) {
  var similar = _ref565.similar,
      end = _ref565.end;

  similar((0, _.main)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref566) {
  var similar = _ref566.similar,
      end = _ref566.end;

  similar((0, _.main)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref567) {
  var similar = _ref567.similar,
      end = _ref567.end;

  similar((0, _.main)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref568) {
  var similar = _ref568.similar,
      end = _ref568.end;

  similar((0, _.main)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref569) {
  var similar = _ref569.similar,
      end = _ref569.end;

  similar((0, _.main)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref570) {
  var similar = _ref570.similar,
      end = _ref570.end;

  similar((0, _.main)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "main#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref571) {
  var equal = _ref571.equal,
      end = _ref571.end;

  equal((0, _snabbdomToHtml2.default)((0, _.main)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<main id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</main>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref572) {
  var equal = _ref572.equal,
      end = _ref572.end;

  equal(toHTMLWithPlugins((0, _.main)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<main id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</main>");
  end();
});

(0, _tap.test)("empty", function (_ref573) {
  var similar = _ref573.similar,
      end = _ref573.end;

  similar((0, _.map)(), { sel: "map" });
  end();
});

(0, _tap.test)("selector", function (_ref574) {
  var similar = _ref574.similar,
      end = _ref574.end;

  similar((0, _.map)({ selector: ".value" }), { sel: "map.value" });
  end();
});

(0, _tap.test)("children string", function (_ref575) {
  var similar = _ref575.similar,
      end = _ref575.end;

  similar((0, _.map)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref576) {
  var similar = _ref576.similar,
      end = _ref576.end;

  similar((0, _.map)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref577) {
  var similar = _ref577.similar,
      end = _ref577.end;

  similar((0, _.map)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref578) {
  var similar = _ref578.similar,
      end = _ref578.end;

  similar((0, _.map)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref579) {
  var similar = _ref579.similar,
      end = _ref579.end;

  similar((0, _.map)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref580) {
  var similar = _ref580.similar,
      end = _ref580.end;

  similar((0, _.map)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref581) {
  var similar = _ref581.similar,
      end = _ref581.end;

  similar((0, _.map)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "map#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref582) {
  var equal = _ref582.equal,
      end = _ref582.end;

  equal((0, _snabbdomToHtml2.default)((0, _.map)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<map id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</map>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref583) {
  var equal = _ref583.equal,
      end = _ref583.end;

  equal(toHTMLWithPlugins((0, _.map)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<map id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</map>");
  end();
});

(0, _tap.test)("empty", function (_ref584) {
  var similar = _ref584.similar,
      end = _ref584.end;

  similar((0, _.mark)(), { sel: "mark" });
  end();
});

(0, _tap.test)("selector", function (_ref585) {
  var similar = _ref585.similar,
      end = _ref585.end;

  similar((0, _.mark)({ selector: ".value" }), { sel: "mark.value" });
  end();
});

(0, _tap.test)("children string", function (_ref586) {
  var similar = _ref586.similar,
      end = _ref586.end;

  similar((0, _.mark)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref587) {
  var similar = _ref587.similar,
      end = _ref587.end;

  similar((0, _.mark)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref588) {
  var similar = _ref588.similar,
      end = _ref588.end;

  similar((0, _.mark)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref589) {
  var similar = _ref589.similar,
      end = _ref589.end;

  similar((0, _.mark)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref590) {
  var similar = _ref590.similar,
      end = _ref590.end;

  similar((0, _.mark)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref591) {
  var similar = _ref591.similar,
      end = _ref591.end;

  similar((0, _.mark)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref592) {
  var similar = _ref592.similar,
      end = _ref592.end;

  similar((0, _.mark)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "mark#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref593) {
  var equal = _ref593.equal,
      end = _ref593.end;

  equal((0, _snabbdomToHtml2.default)((0, _.mark)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<mark id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</mark>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref594) {
  var equal = _ref594.equal,
      end = _ref594.end;

  equal(toHTMLWithPlugins((0, _.mark)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<mark id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</mark>");
  end();
});

(0, _tap.test)("empty", function (_ref595) {
  var similar = _ref595.similar,
      end = _ref595.end;

  similar((0, _.menu)(), { sel: "menu" });
  end();
});

(0, _tap.test)("selector", function (_ref596) {
  var similar = _ref596.similar,
      end = _ref596.end;

  similar((0, _.menu)({ selector: ".value" }), { sel: "menu.value" });
  end();
});

(0, _tap.test)("children string", function (_ref597) {
  var similar = _ref597.similar,
      end = _ref597.end;

  similar((0, _.menu)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref598) {
  var similar = _ref598.similar,
      end = _ref598.end;

  similar((0, _.menu)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref599) {
  var similar = _ref599.similar,
      end = _ref599.end;

  similar((0, _.menu)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref600) {
  var similar = _ref600.similar,
      end = _ref600.end;

  similar((0, _.menu)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref601) {
  var similar = _ref601.similar,
      end = _ref601.end;

  similar((0, _.menu)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref602) {
  var similar = _ref602.similar,
      end = _ref602.end;

  similar((0, _.menu)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref603) {
  var similar = _ref603.similar,
      end = _ref603.end;

  similar((0, _.menu)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "menu#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref604) {
  var equal = _ref604.equal,
      end = _ref604.end;

  equal((0, _snabbdomToHtml2.default)((0, _.menu)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<menu id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</menu>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref605) {
  var equal = _ref605.equal,
      end = _ref605.end;

  equal(toHTMLWithPlugins((0, _.menu)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<menu id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</menu>");
  end();
});

(0, _tap.test)("empty", function (_ref606) {
  var similar = _ref606.similar,
      end = _ref606.end;

  similar((0, _.menuitem)(), { sel: "menuitem" });
  end();
});

(0, _tap.test)("selector", function (_ref607) {
  var similar = _ref607.similar,
      end = _ref607.end;

  similar((0, _.menuitem)({ selector: ".value" }), { sel: "menuitem.value" });
  end();
});

(0, _tap.test)("children string", function (_ref608) {
  var similar = _ref608.similar,
      end = _ref608.end;

  similar((0, _.menuitem)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref609) {
  var similar = _ref609.similar,
      end = _ref609.end;

  similar((0, _.menuitem)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref610) {
  var similar = _ref610.similar,
      end = _ref610.end;

  similar((0, _.menuitem)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref611) {
  var similar = _ref611.similar,
      end = _ref611.end;

  similar((0, _.menuitem)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref612) {
  var similar = _ref612.similar,
      end = _ref612.end;

  similar((0, _.menuitem)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref613) {
  var similar = _ref613.similar,
      end = _ref613.end;

  similar((0, _.menuitem)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref614) {
  var similar = _ref614.similar,
      end = _ref614.end;

  similar((0, _.menuitem)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "menuitem#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref615) {
  var equal = _ref615.equal,
      end = _ref615.end;

  equal((0, _snabbdomToHtml2.default)((0, _.menuitem)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<menuitem id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</menuitem>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref616) {
  var equal = _ref616.equal,
      end = _ref616.end;

  equal(toHTMLWithPlugins((0, _.menuitem)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<menuitem id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</menuitem>");
  end();
});

(0, _tap.test)("empty", function (_ref617) {
  var similar = _ref617.similar,
      end = _ref617.end;

  similar((0, _.meter)(), { sel: "meter" });
  end();
});

(0, _tap.test)("selector", function (_ref618) {
  var similar = _ref618.similar,
      end = _ref618.end;

  similar((0, _.meter)({ selector: ".value" }), { sel: "meter.value" });
  end();
});

(0, _tap.test)("children string", function (_ref619) {
  var similar = _ref619.similar,
      end = _ref619.end;

  similar((0, _.meter)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref620) {
  var similar = _ref620.similar,
      end = _ref620.end;

  similar((0, _.meter)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref621) {
  var similar = _ref621.similar,
      end = _ref621.end;

  similar((0, _.meter)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref622) {
  var similar = _ref622.similar,
      end = _ref622.end;

  similar((0, _.meter)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref623) {
  var similar = _ref623.similar,
      end = _ref623.end;

  similar((0, _.meter)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref624) {
  var similar = _ref624.similar,
      end = _ref624.end;

  similar((0, _.meter)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref625) {
  var similar = _ref625.similar,
      end = _ref625.end;

  similar((0, _.meter)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "meter#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref626) {
  var equal = _ref626.equal,
      end = _ref626.end;

  equal((0, _snabbdomToHtml2.default)((0, _.meter)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<meter id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</meter>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref627) {
  var equal = _ref627.equal,
      end = _ref627.end;

  equal(toHTMLWithPlugins((0, _.meter)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<meter id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</meter>");
  end();
});

(0, _tap.test)("empty", function (_ref628) {
  var similar = _ref628.similar,
      end = _ref628.end;

  similar((0, _.nav)(), { sel: "nav" });
  end();
});

(0, _tap.test)("selector", function (_ref629) {
  var similar = _ref629.similar,
      end = _ref629.end;

  similar((0, _.nav)({ selector: ".value" }), { sel: "nav.value" });
  end();
});

(0, _tap.test)("children string", function (_ref630) {
  var similar = _ref630.similar,
      end = _ref630.end;

  similar((0, _.nav)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref631) {
  var similar = _ref631.similar,
      end = _ref631.end;

  similar((0, _.nav)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref632) {
  var similar = _ref632.similar,
      end = _ref632.end;

  similar((0, _.nav)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref633) {
  var similar = _ref633.similar,
      end = _ref633.end;

  similar((0, _.nav)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref634) {
  var similar = _ref634.similar,
      end = _ref634.end;

  similar((0, _.nav)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref635) {
  var similar = _ref635.similar,
      end = _ref635.end;

  similar((0, _.nav)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref636) {
  var similar = _ref636.similar,
      end = _ref636.end;

  similar((0, _.nav)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "nav#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref637) {
  var equal = _ref637.equal,
      end = _ref637.end;

  equal((0, _snabbdomToHtml2.default)((0, _.nav)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<nav id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</nav>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref638) {
  var equal = _ref638.equal,
      end = _ref638.end;

  equal(toHTMLWithPlugins((0, _.nav)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<nav id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</nav>");
  end();
});

(0, _tap.test)("empty", function (_ref639) {
  var similar = _ref639.similar,
      end = _ref639.end;

  similar((0, _.nobr)(), { sel: "nobr" });
  end();
});

(0, _tap.test)("selector", function (_ref640) {
  var similar = _ref640.similar,
      end = _ref640.end;

  similar((0, _.nobr)({ selector: ".value" }), { sel: "nobr.value" });
  end();
});

(0, _tap.test)("children string", function (_ref641) {
  var similar = _ref641.similar,
      end = _ref641.end;

  similar((0, _.nobr)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref642) {
  var similar = _ref642.similar,
      end = _ref642.end;

  similar((0, _.nobr)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref643) {
  var similar = _ref643.similar,
      end = _ref643.end;

  similar((0, _.nobr)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref644) {
  var similar = _ref644.similar,
      end = _ref644.end;

  similar((0, _.nobr)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref645) {
  var similar = _ref645.similar,
      end = _ref645.end;

  similar((0, _.nobr)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref646) {
  var similar = _ref646.similar,
      end = _ref646.end;

  similar((0, _.nobr)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref647) {
  var similar = _ref647.similar,
      end = _ref647.end;

  similar((0, _.nobr)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "nobr#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref648) {
  var equal = _ref648.equal,
      end = _ref648.end;

  equal((0, _snabbdomToHtml2.default)((0, _.nobr)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<nobr id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</nobr>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref649) {
  var equal = _ref649.equal,
      end = _ref649.end;

  equal(toHTMLWithPlugins((0, _.nobr)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<nobr id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</nobr>");
  end();
});

(0, _tap.test)("empty", function (_ref650) {
  var similar = _ref650.similar,
      end = _ref650.end;

  similar((0, _.noframes)(), { sel: "noframes" });
  end();
});

(0, _tap.test)("selector", function (_ref651) {
  var similar = _ref651.similar,
      end = _ref651.end;

  similar((0, _.noframes)({ selector: ".value" }), { sel: "noframes.value" });
  end();
});

(0, _tap.test)("children string", function (_ref652) {
  var similar = _ref652.similar,
      end = _ref652.end;

  similar((0, _.noframes)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref653) {
  var similar = _ref653.similar,
      end = _ref653.end;

  similar((0, _.noframes)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref654) {
  var similar = _ref654.similar,
      end = _ref654.end;

  similar((0, _.noframes)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref655) {
  var similar = _ref655.similar,
      end = _ref655.end;

  similar((0, _.noframes)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref656) {
  var similar = _ref656.similar,
      end = _ref656.end;

  similar((0, _.noframes)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref657) {
  var similar = _ref657.similar,
      end = _ref657.end;

  similar((0, _.noframes)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref658) {
  var similar = _ref658.similar,
      end = _ref658.end;

  similar((0, _.noframes)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "noframes#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref659) {
  var equal = _ref659.equal,
      end = _ref659.end;

  equal((0, _snabbdomToHtml2.default)((0, _.noframes)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<noframes id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</noframes>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref660) {
  var equal = _ref660.equal,
      end = _ref660.end;

  equal(toHTMLWithPlugins((0, _.noframes)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<noframes id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</noframes>");
  end();
});

(0, _tap.test)("empty", function (_ref661) {
  var similar = _ref661.similar,
      end = _ref661.end;

  similar((0, _.noscript)(), { sel: "noscript" });
  end();
});

(0, _tap.test)("selector", function (_ref662) {
  var similar = _ref662.similar,
      end = _ref662.end;

  similar((0, _.noscript)({ selector: ".value" }), { sel: "noscript.value" });
  end();
});

(0, _tap.test)("children string", function (_ref663) {
  var similar = _ref663.similar,
      end = _ref663.end;

  similar((0, _.noscript)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref664) {
  var similar = _ref664.similar,
      end = _ref664.end;

  similar((0, _.noscript)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref665) {
  var similar = _ref665.similar,
      end = _ref665.end;

  similar((0, _.noscript)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref666) {
  var similar = _ref666.similar,
      end = _ref666.end;

  similar((0, _.noscript)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref667) {
  var similar = _ref667.similar,
      end = _ref667.end;

  similar((0, _.noscript)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref668) {
  var similar = _ref668.similar,
      end = _ref668.end;

  similar((0, _.noscript)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref669) {
  var similar = _ref669.similar,
      end = _ref669.end;

  similar((0, _.noscript)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "noscript#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref670) {
  var equal = _ref670.equal,
      end = _ref670.end;

  equal((0, _snabbdomToHtml2.default)((0, _.noscript)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<noscript id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</noscript>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref671) {
  var equal = _ref671.equal,
      end = _ref671.end;

  equal(toHTMLWithPlugins((0, _.noscript)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<noscript id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</noscript>");
  end();
});

(0, _tap.test)("empty", function (_ref672) {
  var similar = _ref672.similar,
      end = _ref672.end;

  similar((0, _.object)(), { sel: "object" });
  end();
});

(0, _tap.test)("selector", function (_ref673) {
  var similar = _ref673.similar,
      end = _ref673.end;

  similar((0, _.object)({ selector: ".value" }), { sel: "object.value" });
  end();
});

(0, _tap.test)("children string", function (_ref674) {
  var similar = _ref674.similar,
      end = _ref674.end;

  similar((0, _.object)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref675) {
  var similar = _ref675.similar,
      end = _ref675.end;

  similar((0, _.object)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref676) {
  var similar = _ref676.similar,
      end = _ref676.end;

  similar((0, _.object)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref677) {
  var similar = _ref677.similar,
      end = _ref677.end;

  similar((0, _.object)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref678) {
  var similar = _ref678.similar,
      end = _ref678.end;

  similar((0, _.object)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref679) {
  var similar = _ref679.similar,
      end = _ref679.end;

  similar((0, _.object)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref680) {
  var similar = _ref680.similar,
      end = _ref680.end;

  similar((0, _.object)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "object#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref681) {
  var equal = _ref681.equal,
      end = _ref681.end;

  equal((0, _snabbdomToHtml2.default)((0, _.object)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<object id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</object>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref682) {
  var equal = _ref682.equal,
      end = _ref682.end;

  equal(toHTMLWithPlugins((0, _.object)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<object id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</object>");
  end();
});

(0, _tap.test)("empty", function (_ref683) {
  var similar = _ref683.similar,
      end = _ref683.end;

  similar((0, _.ol)(), { sel: "ol" });
  end();
});

(0, _tap.test)("selector", function (_ref684) {
  var similar = _ref684.similar,
      end = _ref684.end;

  similar((0, _.ol)({ selector: ".value" }), { sel: "ol.value" });
  end();
});

(0, _tap.test)("children string", function (_ref685) {
  var similar = _ref685.similar,
      end = _ref685.end;

  similar((0, _.ol)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref686) {
  var similar = _ref686.similar,
      end = _ref686.end;

  similar((0, _.ol)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref687) {
  var similar = _ref687.similar,
      end = _ref687.end;

  similar((0, _.ol)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref688) {
  var similar = _ref688.similar,
      end = _ref688.end;

  similar((0, _.ol)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref689) {
  var similar = _ref689.similar,
      end = _ref689.end;

  similar((0, _.ol)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref690) {
  var similar = _ref690.similar,
      end = _ref690.end;

  similar((0, _.ol)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref691) {
  var similar = _ref691.similar,
      end = _ref691.end;

  similar((0, _.ol)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "ol#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref692) {
  var equal = _ref692.equal,
      end = _ref692.end;

  equal((0, _snabbdomToHtml2.default)((0, _.ol)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ol id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</ol>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref693) {
  var equal = _ref693.equal,
      end = _ref693.end;

  equal(toHTMLWithPlugins((0, _.ol)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ol id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</ol>");
  end();
});

(0, _tap.test)("empty", function (_ref694) {
  var similar = _ref694.similar,
      end = _ref694.end;

  similar((0, _.optgroup)(), { sel: "optgroup" });
  end();
});

(0, _tap.test)("selector", function (_ref695) {
  var similar = _ref695.similar,
      end = _ref695.end;

  similar((0, _.optgroup)({ selector: ".value" }), { sel: "optgroup.value" });
  end();
});

(0, _tap.test)("children string", function (_ref696) {
  var similar = _ref696.similar,
      end = _ref696.end;

  similar((0, _.optgroup)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref697) {
  var similar = _ref697.similar,
      end = _ref697.end;

  similar((0, _.optgroup)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref698) {
  var similar = _ref698.similar,
      end = _ref698.end;

  similar((0, _.optgroup)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref699) {
  var similar = _ref699.similar,
      end = _ref699.end;

  similar((0, _.optgroup)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref700) {
  var similar = _ref700.similar,
      end = _ref700.end;

  similar((0, _.optgroup)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref701) {
  var similar = _ref701.similar,
      end = _ref701.end;

  similar((0, _.optgroup)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref702) {
  var similar = _ref702.similar,
      end = _ref702.end;

  similar((0, _.optgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "optgroup#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref703) {
  var equal = _ref703.equal,
      end = _ref703.end;

  equal((0, _snabbdomToHtml2.default)((0, _.optgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<optgroup id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</optgroup>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref704) {
  var equal = _ref704.equal,
      end = _ref704.end;

  equal(toHTMLWithPlugins((0, _.optgroup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<optgroup id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</optgroup>");
  end();
});

(0, _tap.test)("empty", function (_ref705) {
  var similar = _ref705.similar,
      end = _ref705.end;

  similar((0, _.option)(), { sel: "option" });
  end();
});

(0, _tap.test)("selector", function (_ref706) {
  var similar = _ref706.similar,
      end = _ref706.end;

  similar((0, _.option)({ selector: ".value" }), { sel: "option.value" });
  end();
});

(0, _tap.test)("children string", function (_ref707) {
  var similar = _ref707.similar,
      end = _ref707.end;

  similar((0, _.option)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref708) {
  var similar = _ref708.similar,
      end = _ref708.end;

  similar((0, _.option)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref709) {
  var similar = _ref709.similar,
      end = _ref709.end;

  similar((0, _.option)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref710) {
  var similar = _ref710.similar,
      end = _ref710.end;

  similar((0, _.option)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref711) {
  var similar = _ref711.similar,
      end = _ref711.end;

  similar((0, _.option)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref712) {
  var similar = _ref712.similar,
      end = _ref712.end;

  similar((0, _.option)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref713) {
  var similar = _ref713.similar,
      end = _ref713.end;

  similar((0, _.option)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "option#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref714) {
  var equal = _ref714.equal,
      end = _ref714.end;

  equal((0, _snabbdomToHtml2.default)((0, _.option)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<option id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</option>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref715) {
  var equal = _ref715.equal,
      end = _ref715.end;

  equal(toHTMLWithPlugins((0, _.option)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<option id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</option>");
  end();
});

(0, _tap.test)("empty", function (_ref716) {
  var similar = _ref716.similar,
      end = _ref716.end;

  similar((0, _.output)(), { sel: "output" });
  end();
});

(0, _tap.test)("selector", function (_ref717) {
  var similar = _ref717.similar,
      end = _ref717.end;

  similar((0, _.output)({ selector: ".value" }), { sel: "output.value" });
  end();
});

(0, _tap.test)("children string", function (_ref718) {
  var similar = _ref718.similar,
      end = _ref718.end;

  similar((0, _.output)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref719) {
  var similar = _ref719.similar,
      end = _ref719.end;

  similar((0, _.output)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref720) {
  var similar = _ref720.similar,
      end = _ref720.end;

  similar((0, _.output)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref721) {
  var similar = _ref721.similar,
      end = _ref721.end;

  similar((0, _.output)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref722) {
  var similar = _ref722.similar,
      end = _ref722.end;

  similar((0, _.output)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref723) {
  var similar = _ref723.similar,
      end = _ref723.end;

  similar((0, _.output)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref724) {
  var similar = _ref724.similar,
      end = _ref724.end;

  similar((0, _.output)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "output#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref725) {
  var equal = _ref725.equal,
      end = _ref725.end;

  equal((0, _snabbdomToHtml2.default)((0, _.output)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<output id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</output>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref726) {
  var equal = _ref726.equal,
      end = _ref726.end;

  equal(toHTMLWithPlugins((0, _.output)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<output id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</output>");
  end();
});

(0, _tap.test)("empty", function (_ref727) {
  var similar = _ref727.similar,
      end = _ref727.end;

  similar((0, _.p)(), { sel: "p" });
  end();
});

(0, _tap.test)("selector", function (_ref728) {
  var similar = _ref728.similar,
      end = _ref728.end;

  similar((0, _.p)({ selector: ".value" }), { sel: "p.value" });
  end();
});

(0, _tap.test)("children string", function (_ref729) {
  var similar = _ref729.similar,
      end = _ref729.end;

  similar((0, _.p)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref730) {
  var similar = _ref730.similar,
      end = _ref730.end;

  similar((0, _.p)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref731) {
  var similar = _ref731.similar,
      end = _ref731.end;

  similar((0, _.p)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref732) {
  var similar = _ref732.similar,
      end = _ref732.end;

  similar((0, _.p)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref733) {
  var similar = _ref733.similar,
      end = _ref733.end;

  similar((0, _.p)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref734) {
  var similar = _ref734.similar,
      end = _ref734.end;

  similar((0, _.p)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref735) {
  var similar = _ref735.similar,
      end = _ref735.end;

  similar((0, _.p)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "p#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref736) {
  var equal = _ref736.equal,
      end = _ref736.end;

  equal((0, _snabbdomToHtml2.default)((0, _.p)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<p id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</p>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref737) {
  var equal = _ref737.equal,
      end = _ref737.end;

  equal(toHTMLWithPlugins((0, _.p)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<p id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</p>");
  end();
});

(0, _tap.test)("empty", function (_ref738) {
  var similar = _ref738.similar,
      end = _ref738.end;

  similar((0, _.picture)(), { sel: "picture" });
  end();
});

(0, _tap.test)("selector", function (_ref739) {
  var similar = _ref739.similar,
      end = _ref739.end;

  similar((0, _.picture)({ selector: ".value" }), { sel: "picture.value" });
  end();
});

(0, _tap.test)("children string", function (_ref740) {
  var similar = _ref740.similar,
      end = _ref740.end;

  similar((0, _.picture)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref741) {
  var similar = _ref741.similar,
      end = _ref741.end;

  similar((0, _.picture)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref742) {
  var similar = _ref742.similar,
      end = _ref742.end;

  similar((0, _.picture)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref743) {
  var similar = _ref743.similar,
      end = _ref743.end;

  similar((0, _.picture)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref744) {
  var similar = _ref744.similar,
      end = _ref744.end;

  similar((0, _.picture)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref745) {
  var similar = _ref745.similar,
      end = _ref745.end;

  similar((0, _.picture)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref746) {
  var similar = _ref746.similar,
      end = _ref746.end;

  similar((0, _.picture)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "picture#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref747) {
  var equal = _ref747.equal,
      end = _ref747.end;

  equal((0, _snabbdomToHtml2.default)((0, _.picture)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<picture id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</picture>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref748) {
  var equal = _ref748.equal,
      end = _ref748.end;

  equal(toHTMLWithPlugins((0, _.picture)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<picture id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</picture>");
  end();
});

(0, _tap.test)("empty", function (_ref749) {
  var similar = _ref749.similar,
      end = _ref749.end;

  similar((0, _.pre)(), { sel: "pre" });
  end();
});

(0, _tap.test)("selector", function (_ref750) {
  var similar = _ref750.similar,
      end = _ref750.end;

  similar((0, _.pre)({ selector: ".value" }), { sel: "pre.value" });
  end();
});

(0, _tap.test)("children string", function (_ref751) {
  var similar = _ref751.similar,
      end = _ref751.end;

  similar((0, _.pre)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref752) {
  var similar = _ref752.similar,
      end = _ref752.end;

  similar((0, _.pre)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref753) {
  var similar = _ref753.similar,
      end = _ref753.end;

  similar((0, _.pre)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref754) {
  var similar = _ref754.similar,
      end = _ref754.end;

  similar((0, _.pre)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref755) {
  var similar = _ref755.similar,
      end = _ref755.end;

  similar((0, _.pre)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref756) {
  var similar = _ref756.similar,
      end = _ref756.end;

  similar((0, _.pre)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref757) {
  var similar = _ref757.similar,
      end = _ref757.end;

  similar((0, _.pre)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "pre#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref758) {
  var equal = _ref758.equal,
      end = _ref758.end;

  equal((0, _snabbdomToHtml2.default)((0, _.pre)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<pre id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</pre>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref759) {
  var equal = _ref759.equal,
      end = _ref759.end;

  equal(toHTMLWithPlugins((0, _.pre)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<pre id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</pre>");
  end();
});

(0, _tap.test)("empty", function (_ref760) {
  var similar = _ref760.similar,
      end = _ref760.end;

  similar((0, _.progress)(), { sel: "progress" });
  end();
});

(0, _tap.test)("selector", function (_ref761) {
  var similar = _ref761.similar,
      end = _ref761.end;

  similar((0, _.progress)({ selector: ".value" }), { sel: "progress.value" });
  end();
});

(0, _tap.test)("children string", function (_ref762) {
  var similar = _ref762.similar,
      end = _ref762.end;

  similar((0, _.progress)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref763) {
  var similar = _ref763.similar,
      end = _ref763.end;

  similar((0, _.progress)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref764) {
  var similar = _ref764.similar,
      end = _ref764.end;

  similar((0, _.progress)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref765) {
  var similar = _ref765.similar,
      end = _ref765.end;

  similar((0, _.progress)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref766) {
  var similar = _ref766.similar,
      end = _ref766.end;

  similar((0, _.progress)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref767) {
  var similar = _ref767.similar,
      end = _ref767.end;

  similar((0, _.progress)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref768) {
  var similar = _ref768.similar,
      end = _ref768.end;

  similar((0, _.progress)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "progress#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref769) {
  var equal = _ref769.equal,
      end = _ref769.end;

  equal((0, _snabbdomToHtml2.default)((0, _.progress)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<progress id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</progress>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref770) {
  var equal = _ref770.equal,
      end = _ref770.end;

  equal(toHTMLWithPlugins((0, _.progress)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<progress id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</progress>");
  end();
});

(0, _tap.test)("empty", function (_ref771) {
  var similar = _ref771.similar,
      end = _ref771.end;

  similar((0, _.q)(), { sel: "q" });
  end();
});

(0, _tap.test)("selector", function (_ref772) {
  var similar = _ref772.similar,
      end = _ref772.end;

  similar((0, _.q)({ selector: ".value" }), { sel: "q.value" });
  end();
});

(0, _tap.test)("children string", function (_ref773) {
  var similar = _ref773.similar,
      end = _ref773.end;

  similar((0, _.q)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref774) {
  var similar = _ref774.similar,
      end = _ref774.end;

  similar((0, _.q)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref775) {
  var similar = _ref775.similar,
      end = _ref775.end;

  similar((0, _.q)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref776) {
  var similar = _ref776.similar,
      end = _ref776.end;

  similar((0, _.q)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref777) {
  var similar = _ref777.similar,
      end = _ref777.end;

  similar((0, _.q)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref778) {
  var similar = _ref778.similar,
      end = _ref778.end;

  similar((0, _.q)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref779) {
  var similar = _ref779.similar,
      end = _ref779.end;

  similar((0, _.q)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "q#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref780) {
  var equal = _ref780.equal,
      end = _ref780.end;

  equal((0, _snabbdomToHtml2.default)((0, _.q)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<q id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</q>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref781) {
  var equal = _ref781.equal,
      end = _ref781.end;

  equal(toHTMLWithPlugins((0, _.q)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<q id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</q>");
  end();
});

(0, _tap.test)("empty", function (_ref782) {
  var similar = _ref782.similar,
      end = _ref782.end;

  similar((0, _.rp)(), { sel: "rp" });
  end();
});

(0, _tap.test)("selector", function (_ref783) {
  var similar = _ref783.similar,
      end = _ref783.end;

  similar((0, _.rp)({ selector: ".value" }), { sel: "rp.value" });
  end();
});

(0, _tap.test)("children string", function (_ref784) {
  var similar = _ref784.similar,
      end = _ref784.end;

  similar((0, _.rp)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref785) {
  var similar = _ref785.similar,
      end = _ref785.end;

  similar((0, _.rp)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref786) {
  var similar = _ref786.similar,
      end = _ref786.end;

  similar((0, _.rp)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref787) {
  var similar = _ref787.similar,
      end = _ref787.end;

  similar((0, _.rp)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref788) {
  var similar = _ref788.similar,
      end = _ref788.end;

  similar((0, _.rp)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref789) {
  var similar = _ref789.similar,
      end = _ref789.end;

  similar((0, _.rp)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref790) {
  var similar = _ref790.similar,
      end = _ref790.end;

  similar((0, _.rp)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "rp#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref791) {
  var equal = _ref791.equal,
      end = _ref791.end;

  equal((0, _snabbdomToHtml2.default)((0, _.rp)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<rp id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</rp>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref792) {
  var equal = _ref792.equal,
      end = _ref792.end;

  equal(toHTMLWithPlugins((0, _.rp)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<rp id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</rp>");
  end();
});

(0, _tap.test)("empty", function (_ref793) {
  var similar = _ref793.similar,
      end = _ref793.end;

  similar((0, _.rt)(), { sel: "rt" });
  end();
});

(0, _tap.test)("selector", function (_ref794) {
  var similar = _ref794.similar,
      end = _ref794.end;

  similar((0, _.rt)({ selector: ".value" }), { sel: "rt.value" });
  end();
});

(0, _tap.test)("children string", function (_ref795) {
  var similar = _ref795.similar,
      end = _ref795.end;

  similar((0, _.rt)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref796) {
  var similar = _ref796.similar,
      end = _ref796.end;

  similar((0, _.rt)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref797) {
  var similar = _ref797.similar,
      end = _ref797.end;

  similar((0, _.rt)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref798) {
  var similar = _ref798.similar,
      end = _ref798.end;

  similar((0, _.rt)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref799) {
  var similar = _ref799.similar,
      end = _ref799.end;

  similar((0, _.rt)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref800) {
  var similar = _ref800.similar,
      end = _ref800.end;

  similar((0, _.rt)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref801) {
  var similar = _ref801.similar,
      end = _ref801.end;

  similar((0, _.rt)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "rt#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref802) {
  var equal = _ref802.equal,
      end = _ref802.end;

  equal((0, _snabbdomToHtml2.default)((0, _.rt)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<rt id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</rt>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref803) {
  var equal = _ref803.equal,
      end = _ref803.end;

  equal(toHTMLWithPlugins((0, _.rt)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<rt id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</rt>");
  end();
});

(0, _tap.test)("empty", function (_ref804) {
  var similar = _ref804.similar,
      end = _ref804.end;

  similar((0, _.rtc)(), { sel: "rtc" });
  end();
});

(0, _tap.test)("selector", function (_ref805) {
  var similar = _ref805.similar,
      end = _ref805.end;

  similar((0, _.rtc)({ selector: ".value" }), { sel: "rtc.value" });
  end();
});

(0, _tap.test)("children string", function (_ref806) {
  var similar = _ref806.similar,
      end = _ref806.end;

  similar((0, _.rtc)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref807) {
  var similar = _ref807.similar,
      end = _ref807.end;

  similar((0, _.rtc)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref808) {
  var similar = _ref808.similar,
      end = _ref808.end;

  similar((0, _.rtc)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref809) {
  var similar = _ref809.similar,
      end = _ref809.end;

  similar((0, _.rtc)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref810) {
  var similar = _ref810.similar,
      end = _ref810.end;

  similar((0, _.rtc)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref811) {
  var similar = _ref811.similar,
      end = _ref811.end;

  similar((0, _.rtc)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref812) {
  var similar = _ref812.similar,
      end = _ref812.end;

  similar((0, _.rtc)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "rtc#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref813) {
  var equal = _ref813.equal,
      end = _ref813.end;

  equal((0, _snabbdomToHtml2.default)((0, _.rtc)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<rtc id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</rtc>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref814) {
  var equal = _ref814.equal,
      end = _ref814.end;

  equal(toHTMLWithPlugins((0, _.rtc)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<rtc id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</rtc>");
  end();
});

(0, _tap.test)("empty", function (_ref815) {
  var similar = _ref815.similar,
      end = _ref815.end;

  similar((0, _.ruby)(), { sel: "ruby" });
  end();
});

(0, _tap.test)("selector", function (_ref816) {
  var similar = _ref816.similar,
      end = _ref816.end;

  similar((0, _.ruby)({ selector: ".value" }), { sel: "ruby.value" });
  end();
});

(0, _tap.test)("children string", function (_ref817) {
  var similar = _ref817.similar,
      end = _ref817.end;

  similar((0, _.ruby)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref818) {
  var similar = _ref818.similar,
      end = _ref818.end;

  similar((0, _.ruby)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref819) {
  var similar = _ref819.similar,
      end = _ref819.end;

  similar((0, _.ruby)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref820) {
  var similar = _ref820.similar,
      end = _ref820.end;

  similar((0, _.ruby)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref821) {
  var similar = _ref821.similar,
      end = _ref821.end;

  similar((0, _.ruby)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref822) {
  var similar = _ref822.similar,
      end = _ref822.end;

  similar((0, _.ruby)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref823) {
  var similar = _ref823.similar,
      end = _ref823.end;

  similar((0, _.ruby)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "ruby#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref824) {
  var equal = _ref824.equal,
      end = _ref824.end;

  equal((0, _snabbdomToHtml2.default)((0, _.ruby)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ruby id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</ruby>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref825) {
  var equal = _ref825.equal,
      end = _ref825.end;

  equal(toHTMLWithPlugins((0, _.ruby)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ruby id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</ruby>");
  end();
});

(0, _tap.test)("empty", function (_ref826) {
  var similar = _ref826.similar,
      end = _ref826.end;

  similar((0, _.s)(), { sel: "s" });
  end();
});

(0, _tap.test)("selector", function (_ref827) {
  var similar = _ref827.similar,
      end = _ref827.end;

  similar((0, _.s)({ selector: ".value" }), { sel: "s.value" });
  end();
});

(0, _tap.test)("children string", function (_ref828) {
  var similar = _ref828.similar,
      end = _ref828.end;

  similar((0, _.s)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref829) {
  var similar = _ref829.similar,
      end = _ref829.end;

  similar((0, _.s)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref830) {
  var similar = _ref830.similar,
      end = _ref830.end;

  similar((0, _.s)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref831) {
  var similar = _ref831.similar,
      end = _ref831.end;

  similar((0, _.s)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref832) {
  var similar = _ref832.similar,
      end = _ref832.end;

  similar((0, _.s)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref833) {
  var similar = _ref833.similar,
      end = _ref833.end;

  similar((0, _.s)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref834) {
  var similar = _ref834.similar,
      end = _ref834.end;

  similar((0, _.s)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "s#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref835) {
  var equal = _ref835.equal,
      end = _ref835.end;

  equal((0, _snabbdomToHtml2.default)((0, _.s)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<s id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</s>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref836) {
  var equal = _ref836.equal,
      end = _ref836.end;

  equal(toHTMLWithPlugins((0, _.s)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<s id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</s>");
  end();
});

(0, _tap.test)("empty", function (_ref837) {
  var similar = _ref837.similar,
      end = _ref837.end;

  similar((0, _.samp)(), { sel: "samp" });
  end();
});

(0, _tap.test)("selector", function (_ref838) {
  var similar = _ref838.similar,
      end = _ref838.end;

  similar((0, _.samp)({ selector: ".value" }), { sel: "samp.value" });
  end();
});

(0, _tap.test)("children string", function (_ref839) {
  var similar = _ref839.similar,
      end = _ref839.end;

  similar((0, _.samp)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref840) {
  var similar = _ref840.similar,
      end = _ref840.end;

  similar((0, _.samp)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref841) {
  var similar = _ref841.similar,
      end = _ref841.end;

  similar((0, _.samp)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref842) {
  var similar = _ref842.similar,
      end = _ref842.end;

  similar((0, _.samp)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref843) {
  var similar = _ref843.similar,
      end = _ref843.end;

  similar((0, _.samp)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref844) {
  var similar = _ref844.similar,
      end = _ref844.end;

  similar((0, _.samp)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref845) {
  var similar = _ref845.similar,
      end = _ref845.end;

  similar((0, _.samp)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "samp#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref846) {
  var equal = _ref846.equal,
      end = _ref846.end;

  equal((0, _snabbdomToHtml2.default)((0, _.samp)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<samp id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</samp>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref847) {
  var equal = _ref847.equal,
      end = _ref847.end;

  equal(toHTMLWithPlugins((0, _.samp)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<samp id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</samp>");
  end();
});

(0, _tap.test)("empty", function (_ref848) {
  var similar = _ref848.similar,
      end = _ref848.end;

  similar((0, _.script)(), { sel: "script" });
  end();
});

(0, _tap.test)("selector", function (_ref849) {
  var similar = _ref849.similar,
      end = _ref849.end;

  similar((0, _.script)({ selector: ".value" }), { sel: "script.value" });
  end();
});

(0, _tap.test)("children string", function (_ref850) {
  var similar = _ref850.similar,
      end = _ref850.end;

  similar((0, _.script)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref851) {
  var similar = _ref851.similar,
      end = _ref851.end;

  similar((0, _.script)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref852) {
  var similar = _ref852.similar,
      end = _ref852.end;

  similar((0, _.script)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref853) {
  var similar = _ref853.similar,
      end = _ref853.end;

  similar((0, _.script)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref854) {
  var similar = _ref854.similar,
      end = _ref854.end;

  similar((0, _.script)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref855) {
  var similar = _ref855.similar,
      end = _ref855.end;

  similar((0, _.script)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref856) {
  var similar = _ref856.similar,
      end = _ref856.end;

  similar((0, _.script)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "script#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref857) {
  var equal = _ref857.equal,
      end = _ref857.end;

  equal((0, _snabbdomToHtml2.default)((0, _.script)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<script id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</script>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref858) {
  var equal = _ref858.equal,
      end = _ref858.end;

  equal(toHTMLWithPlugins((0, _.script)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<script id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</script>");
  end();
});

(0, _tap.test)("empty", function (_ref859) {
  var similar = _ref859.similar,
      end = _ref859.end;

  similar((0, _.section)(), { sel: "section" });
  end();
});

(0, _tap.test)("selector", function (_ref860) {
  var similar = _ref860.similar,
      end = _ref860.end;

  similar((0, _.section)({ selector: ".value" }), { sel: "section.value" });
  end();
});

(0, _tap.test)("children string", function (_ref861) {
  var similar = _ref861.similar,
      end = _ref861.end;

  similar((0, _.section)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref862) {
  var similar = _ref862.similar,
      end = _ref862.end;

  similar((0, _.section)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref863) {
  var similar = _ref863.similar,
      end = _ref863.end;

  similar((0, _.section)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref864) {
  var similar = _ref864.similar,
      end = _ref864.end;

  similar((0, _.section)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref865) {
  var similar = _ref865.similar,
      end = _ref865.end;

  similar((0, _.section)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref866) {
  var similar = _ref866.similar,
      end = _ref866.end;

  similar((0, _.section)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref867) {
  var similar = _ref867.similar,
      end = _ref867.end;

  similar((0, _.section)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "section#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref868) {
  var equal = _ref868.equal,
      end = _ref868.end;

  equal((0, _snabbdomToHtml2.default)((0, _.section)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<section id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</section>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref869) {
  var equal = _ref869.equal,
      end = _ref869.end;

  equal(toHTMLWithPlugins((0, _.section)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<section id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</section>");
  end();
});

(0, _tap.test)("empty", function (_ref870) {
  var similar = _ref870.similar,
      end = _ref870.end;

  similar((0, _.select)(), { sel: "select" });
  end();
});

(0, _tap.test)("selector", function (_ref871) {
  var similar = _ref871.similar,
      end = _ref871.end;

  similar((0, _.select)({ selector: ".value" }), { sel: "select.value" });
  end();
});

(0, _tap.test)("children string", function (_ref872) {
  var similar = _ref872.similar,
      end = _ref872.end;

  similar((0, _.select)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref873) {
  var similar = _ref873.similar,
      end = _ref873.end;

  similar((0, _.select)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref874) {
  var similar = _ref874.similar,
      end = _ref874.end;

  similar((0, _.select)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref875) {
  var similar = _ref875.similar,
      end = _ref875.end;

  similar((0, _.select)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref876) {
  var similar = _ref876.similar,
      end = _ref876.end;

  similar((0, _.select)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref877) {
  var similar = _ref877.similar,
      end = _ref877.end;

  similar((0, _.select)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref878) {
  var similar = _ref878.similar,
      end = _ref878.end;

  similar((0, _.select)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "select#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref879) {
  var equal = _ref879.equal,
      end = _ref879.end;

  equal((0, _snabbdomToHtml2.default)((0, _.select)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<select id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</select>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref880) {
  var equal = _ref880.equal,
      end = _ref880.end;

  equal(toHTMLWithPlugins((0, _.select)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<select id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</select>");
  end();
});

(0, _tap.test)("empty", function (_ref881) {
  var similar = _ref881.similar,
      end = _ref881.end;

  similar((0, _.small)(), { sel: "small" });
  end();
});

(0, _tap.test)("selector", function (_ref882) {
  var similar = _ref882.similar,
      end = _ref882.end;

  similar((0, _.small)({ selector: ".value" }), { sel: "small.value" });
  end();
});

(0, _tap.test)("children string", function (_ref883) {
  var similar = _ref883.similar,
      end = _ref883.end;

  similar((0, _.small)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref884) {
  var similar = _ref884.similar,
      end = _ref884.end;

  similar((0, _.small)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref885) {
  var similar = _ref885.similar,
      end = _ref885.end;

  similar((0, _.small)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref886) {
  var similar = _ref886.similar,
      end = _ref886.end;

  similar((0, _.small)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref887) {
  var similar = _ref887.similar,
      end = _ref887.end;

  similar((0, _.small)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref888) {
  var similar = _ref888.similar,
      end = _ref888.end;

  similar((0, _.small)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref889) {
  var similar = _ref889.similar,
      end = _ref889.end;

  similar((0, _.small)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "small#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref890) {
  var equal = _ref890.equal,
      end = _ref890.end;

  equal((0, _snabbdomToHtml2.default)((0, _.small)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<small id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</small>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref891) {
  var equal = _ref891.equal,
      end = _ref891.end;

  equal(toHTMLWithPlugins((0, _.small)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<small id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</small>");
  end();
});

(0, _tap.test)("empty", function (_ref892) {
  var similar = _ref892.similar,
      end = _ref892.end;

  similar((0, _.span)(), { sel: "span" });
  end();
});

(0, _tap.test)("selector", function (_ref893) {
  var similar = _ref893.similar,
      end = _ref893.end;

  similar((0, _.span)({ selector: ".value" }), { sel: "span.value" });
  end();
});

(0, _tap.test)("children string", function (_ref894) {
  var similar = _ref894.similar,
      end = _ref894.end;

  similar((0, _.span)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref895) {
  var similar = _ref895.similar,
      end = _ref895.end;

  similar((0, _.span)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref896) {
  var similar = _ref896.similar,
      end = _ref896.end;

  similar((0, _.span)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref897) {
  var similar = _ref897.similar,
      end = _ref897.end;

  similar((0, _.span)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref898) {
  var similar = _ref898.similar,
      end = _ref898.end;

  similar((0, _.span)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref899) {
  var similar = _ref899.similar,
      end = _ref899.end;

  similar((0, _.span)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref900) {
  var similar = _ref900.similar,
      end = _ref900.end;

  similar((0, _.span)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "span#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref901) {
  var equal = _ref901.equal,
      end = _ref901.end;

  equal((0, _snabbdomToHtml2.default)((0, _.span)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<span id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</span>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref902) {
  var equal = _ref902.equal,
      end = _ref902.end;

  equal(toHTMLWithPlugins((0, _.span)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<span id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</span>");
  end();
});

(0, _tap.test)("empty", function (_ref903) {
  var similar = _ref903.similar,
      end = _ref903.end;

  similar((0, _.strong)(), { sel: "strong" });
  end();
});

(0, _tap.test)("selector", function (_ref904) {
  var similar = _ref904.similar,
      end = _ref904.end;

  similar((0, _.strong)({ selector: ".value" }), { sel: "strong.value" });
  end();
});

(0, _tap.test)("children string", function (_ref905) {
  var similar = _ref905.similar,
      end = _ref905.end;

  similar((0, _.strong)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref906) {
  var similar = _ref906.similar,
      end = _ref906.end;

  similar((0, _.strong)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref907) {
  var similar = _ref907.similar,
      end = _ref907.end;

  similar((0, _.strong)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref908) {
  var similar = _ref908.similar,
      end = _ref908.end;

  similar((0, _.strong)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref909) {
  var similar = _ref909.similar,
      end = _ref909.end;

  similar((0, _.strong)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref910) {
  var similar = _ref910.similar,
      end = _ref910.end;

  similar((0, _.strong)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref911) {
  var similar = _ref911.similar,
      end = _ref911.end;

  similar((0, _.strong)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "strong#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref912) {
  var equal = _ref912.equal,
      end = _ref912.end;

  equal((0, _snabbdomToHtml2.default)((0, _.strong)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<strong id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</strong>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref913) {
  var equal = _ref913.equal,
      end = _ref913.end;

  equal(toHTMLWithPlugins((0, _.strong)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<strong id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</strong>");
  end();
});

(0, _tap.test)("empty", function (_ref914) {
  var similar = _ref914.similar,
      end = _ref914.end;

  similar((0, _.style)(), { sel: "style" });
  end();
});

(0, _tap.test)("selector", function (_ref915) {
  var similar = _ref915.similar,
      end = _ref915.end;

  similar((0, _.style)({ selector: ".value" }), { sel: "style.value" });
  end();
});

(0, _tap.test)("children string", function (_ref916) {
  var similar = _ref916.similar,
      end = _ref916.end;

  similar((0, _.style)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref917) {
  var similar = _ref917.similar,
      end = _ref917.end;

  similar((0, _.style)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref918) {
  var similar = _ref918.similar,
      end = _ref918.end;

  similar((0, _.style)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref919) {
  var similar = _ref919.similar,
      end = _ref919.end;

  similar((0, _.style)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref920) {
  var similar = _ref920.similar,
      end = _ref920.end;

  similar((0, _.style)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref921) {
  var similar = _ref921.similar,
      end = _ref921.end;

  similar((0, _.style)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref922) {
  var similar = _ref922.similar,
      end = _ref922.end;

  similar((0, _.style)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "style#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref923) {
  var equal = _ref923.equal,
      end = _ref923.end;

  equal((0, _snabbdomToHtml2.default)((0, _.style)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<style id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</style>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref924) {
  var equal = _ref924.equal,
      end = _ref924.end;

  equal(toHTMLWithPlugins((0, _.style)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<style id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</style>");
  end();
});

(0, _tap.test)("empty", function (_ref925) {
  var similar = _ref925.similar,
      end = _ref925.end;

  similar((0, _.sub)(), { sel: "sub" });
  end();
});

(0, _tap.test)("selector", function (_ref926) {
  var similar = _ref926.similar,
      end = _ref926.end;

  similar((0, _.sub)({ selector: ".value" }), { sel: "sub.value" });
  end();
});

(0, _tap.test)("children string", function (_ref927) {
  var similar = _ref927.similar,
      end = _ref927.end;

  similar((0, _.sub)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref928) {
  var similar = _ref928.similar,
      end = _ref928.end;

  similar((0, _.sub)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref929) {
  var similar = _ref929.similar,
      end = _ref929.end;

  similar((0, _.sub)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref930) {
  var similar = _ref930.similar,
      end = _ref930.end;

  similar((0, _.sub)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref931) {
  var similar = _ref931.similar,
      end = _ref931.end;

  similar((0, _.sub)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref932) {
  var similar = _ref932.similar,
      end = _ref932.end;

  similar((0, _.sub)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref933) {
  var similar = _ref933.similar,
      end = _ref933.end;

  similar((0, _.sub)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "sub#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref934) {
  var equal = _ref934.equal,
      end = _ref934.end;

  equal((0, _snabbdomToHtml2.default)((0, _.sub)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<sub id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</sub>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref935) {
  var equal = _ref935.equal,
      end = _ref935.end;

  equal(toHTMLWithPlugins((0, _.sub)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<sub id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</sub>");
  end();
});

(0, _tap.test)("empty", function (_ref936) {
  var similar = _ref936.similar,
      end = _ref936.end;

  similar((0, _.summary)(), { sel: "summary" });
  end();
});

(0, _tap.test)("selector", function (_ref937) {
  var similar = _ref937.similar,
      end = _ref937.end;

  similar((0, _.summary)({ selector: ".value" }), { sel: "summary.value" });
  end();
});

(0, _tap.test)("children string", function (_ref938) {
  var similar = _ref938.similar,
      end = _ref938.end;

  similar((0, _.summary)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref939) {
  var similar = _ref939.similar,
      end = _ref939.end;

  similar((0, _.summary)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref940) {
  var similar = _ref940.similar,
      end = _ref940.end;

  similar((0, _.summary)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref941) {
  var similar = _ref941.similar,
      end = _ref941.end;

  similar((0, _.summary)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref942) {
  var similar = _ref942.similar,
      end = _ref942.end;

  similar((0, _.summary)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref943) {
  var similar = _ref943.similar,
      end = _ref943.end;

  similar((0, _.summary)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref944) {
  var similar = _ref944.similar,
      end = _ref944.end;

  similar((0, _.summary)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "summary#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref945) {
  var equal = _ref945.equal,
      end = _ref945.end;

  equal((0, _snabbdomToHtml2.default)((0, _.summary)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<summary id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</summary>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref946) {
  var equal = _ref946.equal,
      end = _ref946.end;

  equal(toHTMLWithPlugins((0, _.summary)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<summary id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</summary>");
  end();
});

(0, _tap.test)("empty", function (_ref947) {
  var similar = _ref947.similar,
      end = _ref947.end;

  similar((0, _.sup)(), { sel: "sup" });
  end();
});

(0, _tap.test)("selector", function (_ref948) {
  var similar = _ref948.similar,
      end = _ref948.end;

  similar((0, _.sup)({ selector: ".value" }), { sel: "sup.value" });
  end();
});

(0, _tap.test)("children string", function (_ref949) {
  var similar = _ref949.similar,
      end = _ref949.end;

  similar((0, _.sup)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref950) {
  var similar = _ref950.similar,
      end = _ref950.end;

  similar((0, _.sup)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref951) {
  var similar = _ref951.similar,
      end = _ref951.end;

  similar((0, _.sup)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref952) {
  var similar = _ref952.similar,
      end = _ref952.end;

  similar((0, _.sup)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref953) {
  var similar = _ref953.similar,
      end = _ref953.end;

  similar((0, _.sup)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref954) {
  var similar = _ref954.similar,
      end = _ref954.end;

  similar((0, _.sup)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref955) {
  var similar = _ref955.similar,
      end = _ref955.end;

  similar((0, _.sup)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "sup#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref956) {
  var equal = _ref956.equal,
      end = _ref956.end;

  equal((0, _snabbdomToHtml2.default)((0, _.sup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<sup id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</sup>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref957) {
  var equal = _ref957.equal,
      end = _ref957.end;

  equal(toHTMLWithPlugins((0, _.sup)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<sup id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</sup>");
  end();
});

(0, _tap.test)("empty", function (_ref958) {
  var similar = _ref958.similar,
      end = _ref958.end;

  similar((0, _.table)(), { sel: "table" });
  end();
});

(0, _tap.test)("selector", function (_ref959) {
  var similar = _ref959.similar,
      end = _ref959.end;

  similar((0, _.table)({ selector: ".value" }), { sel: "table.value" });
  end();
});

(0, _tap.test)("children string", function (_ref960) {
  var similar = _ref960.similar,
      end = _ref960.end;

  similar((0, _.table)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref961) {
  var similar = _ref961.similar,
      end = _ref961.end;

  similar((0, _.table)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref962) {
  var similar = _ref962.similar,
      end = _ref962.end;

  similar((0, _.table)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref963) {
  var similar = _ref963.similar,
      end = _ref963.end;

  similar((0, _.table)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref964) {
  var similar = _ref964.similar,
      end = _ref964.end;

  similar((0, _.table)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref965) {
  var similar = _ref965.similar,
      end = _ref965.end;

  similar((0, _.table)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref966) {
  var similar = _ref966.similar,
      end = _ref966.end;

  similar((0, _.table)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "table#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref967) {
  var equal = _ref967.equal,
      end = _ref967.end;

  equal((0, _snabbdomToHtml2.default)((0, _.table)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<table id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</table>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref968) {
  var equal = _ref968.equal,
      end = _ref968.end;

  equal(toHTMLWithPlugins((0, _.table)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<table id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</table>");
  end();
});

(0, _tap.test)("empty", function (_ref969) {
  var similar = _ref969.similar,
      end = _ref969.end;

  similar((0, _.tbody)(), { sel: "tbody" });
  end();
});

(0, _tap.test)("selector", function (_ref970) {
  var similar = _ref970.similar,
      end = _ref970.end;

  similar((0, _.tbody)({ selector: ".value" }), { sel: "tbody.value" });
  end();
});

(0, _tap.test)("children string", function (_ref971) {
  var similar = _ref971.similar,
      end = _ref971.end;

  similar((0, _.tbody)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref972) {
  var similar = _ref972.similar,
      end = _ref972.end;

  similar((0, _.tbody)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref973) {
  var similar = _ref973.similar,
      end = _ref973.end;

  similar((0, _.tbody)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref974) {
  var similar = _ref974.similar,
      end = _ref974.end;

  similar((0, _.tbody)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref975) {
  var similar = _ref975.similar,
      end = _ref975.end;

  similar((0, _.tbody)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref976) {
  var similar = _ref976.similar,
      end = _ref976.end;

  similar((0, _.tbody)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref977) {
  var similar = _ref977.similar,
      end = _ref977.end;

  similar((0, _.tbody)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "tbody#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref978) {
  var equal = _ref978.equal,
      end = _ref978.end;

  equal((0, _snabbdomToHtml2.default)((0, _.tbody)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<tbody id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</tbody>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref979) {
  var equal = _ref979.equal,
      end = _ref979.end;

  equal(toHTMLWithPlugins((0, _.tbody)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<tbody id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</tbody>");
  end();
});

(0, _tap.test)("empty", function (_ref980) {
  var similar = _ref980.similar,
      end = _ref980.end;

  similar((0, _.td)(), { sel: "td" });
  end();
});

(0, _tap.test)("selector", function (_ref981) {
  var similar = _ref981.similar,
      end = _ref981.end;

  similar((0, _.td)({ selector: ".value" }), { sel: "td.value" });
  end();
});

(0, _tap.test)("children string", function (_ref982) {
  var similar = _ref982.similar,
      end = _ref982.end;

  similar((0, _.td)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref983) {
  var similar = _ref983.similar,
      end = _ref983.end;

  similar((0, _.td)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref984) {
  var similar = _ref984.similar,
      end = _ref984.end;

  similar((0, _.td)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref985) {
  var similar = _ref985.similar,
      end = _ref985.end;

  similar((0, _.td)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref986) {
  var similar = _ref986.similar,
      end = _ref986.end;

  similar((0, _.td)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref987) {
  var similar = _ref987.similar,
      end = _ref987.end;

  similar((0, _.td)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref988) {
  var similar = _ref988.similar,
      end = _ref988.end;

  similar((0, _.td)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "td#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref989) {
  var equal = _ref989.equal,
      end = _ref989.end;

  equal((0, _snabbdomToHtml2.default)((0, _.td)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<td id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</td>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref990) {
  var equal = _ref990.equal,
      end = _ref990.end;

  equal(toHTMLWithPlugins((0, _.td)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<td id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</td>");
  end();
});

(0, _tap.test)("empty", function (_ref991) {
  var similar = _ref991.similar,
      end = _ref991.end;

  similar((0, _.template)(), { sel: "template" });
  end();
});

(0, _tap.test)("selector", function (_ref992) {
  var similar = _ref992.similar,
      end = _ref992.end;

  similar((0, _.template)({ selector: ".value" }), { sel: "template.value" });
  end();
});

(0, _tap.test)("children string", function (_ref993) {
  var similar = _ref993.similar,
      end = _ref993.end;

  similar((0, _.template)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref994) {
  var similar = _ref994.similar,
      end = _ref994.end;

  similar((0, _.template)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref995) {
  var similar = _ref995.similar,
      end = _ref995.end;

  similar((0, _.template)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref996) {
  var similar = _ref996.similar,
      end = _ref996.end;

  similar((0, _.template)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref997) {
  var similar = _ref997.similar,
      end = _ref997.end;

  similar((0, _.template)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref998) {
  var similar = _ref998.similar,
      end = _ref998.end;

  similar((0, _.template)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref999) {
  var similar = _ref999.similar,
      end = _ref999.end;

  similar((0, _.template)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "template#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1000) {
  var equal = _ref1000.equal,
      end = _ref1000.end;

  equal((0, _snabbdomToHtml2.default)((0, _.template)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<template id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</template>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1001) {
  var equal = _ref1001.equal,
      end = _ref1001.end;

  equal(toHTMLWithPlugins((0, _.template)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<template id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</template>");
  end();
});

(0, _tap.test)("empty", function (_ref1002) {
  var similar = _ref1002.similar,
      end = _ref1002.end;

  similar((0, _.textarea)(), { sel: "textarea" });
  end();
});

(0, _tap.test)("selector", function (_ref1003) {
  var similar = _ref1003.similar,
      end = _ref1003.end;

  similar((0, _.textarea)({ selector: ".value" }), { sel: "textarea.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1004) {
  var similar = _ref1004.similar,
      end = _ref1004.end;

  similar((0, _.textarea)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1005) {
  var similar = _ref1005.similar,
      end = _ref1005.end;

  similar((0, _.textarea)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1006) {
  var similar = _ref1006.similar,
      end = _ref1006.end;

  similar((0, _.textarea)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1007) {
  var similar = _ref1007.similar,
      end = _ref1007.end;

  similar((0, _.textarea)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1008) {
  var similar = _ref1008.similar,
      end = _ref1008.end;

  similar((0, _.textarea)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1009) {
  var similar = _ref1009.similar,
      end = _ref1009.end;

  similar((0, _.textarea)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1010) {
  var similar = _ref1010.similar,
      end = _ref1010.end;

  similar((0, _.textarea)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "textarea#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1011) {
  var equal = _ref1011.equal,
      end = _ref1011.end;

  equal((0, _snabbdomToHtml2.default)((0, _.textarea)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<textarea id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</textarea>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1012) {
  var equal = _ref1012.equal,
      end = _ref1012.end;

  equal(toHTMLWithPlugins((0, _.textarea)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<textarea id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</textarea>");
  end();
});

(0, _tap.test)("empty", function (_ref1013) {
  var similar = _ref1013.similar,
      end = _ref1013.end;

  similar((0, _.tfoot)(), { sel: "tfoot" });
  end();
});

(0, _tap.test)("selector", function (_ref1014) {
  var similar = _ref1014.similar,
      end = _ref1014.end;

  similar((0, _.tfoot)({ selector: ".value" }), { sel: "tfoot.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1015) {
  var similar = _ref1015.similar,
      end = _ref1015.end;

  similar((0, _.tfoot)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1016) {
  var similar = _ref1016.similar,
      end = _ref1016.end;

  similar((0, _.tfoot)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1017) {
  var similar = _ref1017.similar,
      end = _ref1017.end;

  similar((0, _.tfoot)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1018) {
  var similar = _ref1018.similar,
      end = _ref1018.end;

  similar((0, _.tfoot)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1019) {
  var similar = _ref1019.similar,
      end = _ref1019.end;

  similar((0, _.tfoot)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1020) {
  var similar = _ref1020.similar,
      end = _ref1020.end;

  similar((0, _.tfoot)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1021) {
  var similar = _ref1021.similar,
      end = _ref1021.end;

  similar((0, _.tfoot)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "tfoot#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1022) {
  var equal = _ref1022.equal,
      end = _ref1022.end;

  equal((0, _snabbdomToHtml2.default)((0, _.tfoot)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<tfoot id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</tfoot>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1023) {
  var equal = _ref1023.equal,
      end = _ref1023.end;

  equal(toHTMLWithPlugins((0, _.tfoot)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<tfoot id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</tfoot>");
  end();
});

(0, _tap.test)("empty", function (_ref1024) {
  var similar = _ref1024.similar,
      end = _ref1024.end;

  similar((0, _.th)(), { sel: "th" });
  end();
});

(0, _tap.test)("selector", function (_ref1025) {
  var similar = _ref1025.similar,
      end = _ref1025.end;

  similar((0, _.th)({ selector: ".value" }), { sel: "th.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1026) {
  var similar = _ref1026.similar,
      end = _ref1026.end;

  similar((0, _.th)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1027) {
  var similar = _ref1027.similar,
      end = _ref1027.end;

  similar((0, _.th)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1028) {
  var similar = _ref1028.similar,
      end = _ref1028.end;

  similar((0, _.th)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1029) {
  var similar = _ref1029.similar,
      end = _ref1029.end;

  similar((0, _.th)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1030) {
  var similar = _ref1030.similar,
      end = _ref1030.end;

  similar((0, _.th)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1031) {
  var similar = _ref1031.similar,
      end = _ref1031.end;

  similar((0, _.th)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1032) {
  var similar = _ref1032.similar,
      end = _ref1032.end;

  similar((0, _.th)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "th#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1033) {
  var equal = _ref1033.equal,
      end = _ref1033.end;

  equal((0, _snabbdomToHtml2.default)((0, _.th)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<th id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</th>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1034) {
  var equal = _ref1034.equal,
      end = _ref1034.end;

  equal(toHTMLWithPlugins((0, _.th)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<th id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</th>");
  end();
});

(0, _tap.test)("empty", function (_ref1035) {
  var similar = _ref1035.similar,
      end = _ref1035.end;

  similar((0, _.thead)(), { sel: "thead" });
  end();
});

(0, _tap.test)("selector", function (_ref1036) {
  var similar = _ref1036.similar,
      end = _ref1036.end;

  similar((0, _.thead)({ selector: ".value" }), { sel: "thead.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1037) {
  var similar = _ref1037.similar,
      end = _ref1037.end;

  similar((0, _.thead)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1038) {
  var similar = _ref1038.similar,
      end = _ref1038.end;

  similar((0, _.thead)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1039) {
  var similar = _ref1039.similar,
      end = _ref1039.end;

  similar((0, _.thead)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1040) {
  var similar = _ref1040.similar,
      end = _ref1040.end;

  similar((0, _.thead)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1041) {
  var similar = _ref1041.similar,
      end = _ref1041.end;

  similar((0, _.thead)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1042) {
  var similar = _ref1042.similar,
      end = _ref1042.end;

  similar((0, _.thead)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1043) {
  var similar = _ref1043.similar,
      end = _ref1043.end;

  similar((0, _.thead)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "thead#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1044) {
  var equal = _ref1044.equal,
      end = _ref1044.end;

  equal((0, _snabbdomToHtml2.default)((0, _.thead)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<thead id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</thead>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1045) {
  var equal = _ref1045.equal,
      end = _ref1045.end;

  equal(toHTMLWithPlugins((0, _.thead)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<thead id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</thead>");
  end();
});

(0, _tap.test)("empty", function (_ref1046) {
  var similar = _ref1046.similar,
      end = _ref1046.end;

  similar((0, _.time)(), { sel: "time" });
  end();
});

(0, _tap.test)("selector", function (_ref1047) {
  var similar = _ref1047.similar,
      end = _ref1047.end;

  similar((0, _.time)({ selector: ".value" }), { sel: "time.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1048) {
  var similar = _ref1048.similar,
      end = _ref1048.end;

  similar((0, _.time)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1049) {
  var similar = _ref1049.similar,
      end = _ref1049.end;

  similar((0, _.time)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1050) {
  var similar = _ref1050.similar,
      end = _ref1050.end;

  similar((0, _.time)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1051) {
  var similar = _ref1051.similar,
      end = _ref1051.end;

  similar((0, _.time)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1052) {
  var similar = _ref1052.similar,
      end = _ref1052.end;

  similar((0, _.time)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1053) {
  var similar = _ref1053.similar,
      end = _ref1053.end;

  similar((0, _.time)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1054) {
  var similar = _ref1054.similar,
      end = _ref1054.end;

  similar((0, _.time)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "time#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1055) {
  var equal = _ref1055.equal,
      end = _ref1055.end;

  equal((0, _snabbdomToHtml2.default)((0, _.time)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<time id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</time>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1056) {
  var equal = _ref1056.equal,
      end = _ref1056.end;

  equal(toHTMLWithPlugins((0, _.time)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<time id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</time>");
  end();
});

(0, _tap.test)("empty", function (_ref1057) {
  var similar = _ref1057.similar,
      end = _ref1057.end;

  similar((0, _.title)(), { sel: "title" });
  end();
});

(0, _tap.test)("selector", function (_ref1058) {
  var similar = _ref1058.similar,
      end = _ref1058.end;

  similar((0, _.title)({ selector: ".value" }), { sel: "title.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1059) {
  var similar = _ref1059.similar,
      end = _ref1059.end;

  similar((0, _.title)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1060) {
  var similar = _ref1060.similar,
      end = _ref1060.end;

  similar((0, _.title)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1061) {
  var similar = _ref1061.similar,
      end = _ref1061.end;

  similar((0, _.title)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1062) {
  var similar = _ref1062.similar,
      end = _ref1062.end;

  similar((0, _.title)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1063) {
  var similar = _ref1063.similar,
      end = _ref1063.end;

  similar((0, _.title)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1064) {
  var similar = _ref1064.similar,
      end = _ref1064.end;

  similar((0, _.title)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1065) {
  var similar = _ref1065.similar,
      end = _ref1065.end;

  similar((0, _.title)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "title#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1066) {
  var equal = _ref1066.equal,
      end = _ref1066.end;

  equal((0, _snabbdomToHtml2.default)((0, _.title)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<title id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</title>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1067) {
  var equal = _ref1067.equal,
      end = _ref1067.end;

  equal(toHTMLWithPlugins((0, _.title)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<title id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</title>");
  end();
});

(0, _tap.test)("empty", function (_ref1068) {
  var similar = _ref1068.similar,
      end = _ref1068.end;

  similar((0, _.tr)(), { sel: "tr" });
  end();
});

(0, _tap.test)("selector", function (_ref1069) {
  var similar = _ref1069.similar,
      end = _ref1069.end;

  similar((0, _.tr)({ selector: ".value" }), { sel: "tr.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1070) {
  var similar = _ref1070.similar,
      end = _ref1070.end;

  similar((0, _.tr)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1071) {
  var similar = _ref1071.similar,
      end = _ref1071.end;

  similar((0, _.tr)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1072) {
  var similar = _ref1072.similar,
      end = _ref1072.end;

  similar((0, _.tr)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1073) {
  var similar = _ref1073.similar,
      end = _ref1073.end;

  similar((0, _.tr)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1074) {
  var similar = _ref1074.similar,
      end = _ref1074.end;

  similar((0, _.tr)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1075) {
  var similar = _ref1075.similar,
      end = _ref1075.end;

  similar((0, _.tr)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1076) {
  var similar = _ref1076.similar,
      end = _ref1076.end;

  similar((0, _.tr)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "tr#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1077) {
  var equal = _ref1077.equal,
      end = _ref1077.end;

  equal((0, _snabbdomToHtml2.default)((0, _.tr)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<tr id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</tr>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1078) {
  var equal = _ref1078.equal,
      end = _ref1078.end;

  equal(toHTMLWithPlugins((0, _.tr)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<tr id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</tr>");
  end();
});

(0, _tap.test)("empty", function (_ref1079) {
  var similar = _ref1079.similar,
      end = _ref1079.end;

  similar((0, _.u)(), { sel: "u" });
  end();
});

(0, _tap.test)("selector", function (_ref1080) {
  var similar = _ref1080.similar,
      end = _ref1080.end;

  similar((0, _.u)({ selector: ".value" }), { sel: "u.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1081) {
  var similar = _ref1081.similar,
      end = _ref1081.end;

  similar((0, _.u)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1082) {
  var similar = _ref1082.similar,
      end = _ref1082.end;

  similar((0, _.u)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1083) {
  var similar = _ref1083.similar,
      end = _ref1083.end;

  similar((0, _.u)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1084) {
  var similar = _ref1084.similar,
      end = _ref1084.end;

  similar((0, _.u)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1085) {
  var similar = _ref1085.similar,
      end = _ref1085.end;

  similar((0, _.u)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1086) {
  var similar = _ref1086.similar,
      end = _ref1086.end;

  similar((0, _.u)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1087) {
  var similar = _ref1087.similar,
      end = _ref1087.end;

  similar((0, _.u)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "u#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1088) {
  var equal = _ref1088.equal,
      end = _ref1088.end;

  equal((0, _snabbdomToHtml2.default)((0, _.u)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<u id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</u>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1089) {
  var equal = _ref1089.equal,
      end = _ref1089.end;

  equal(toHTMLWithPlugins((0, _.u)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<u id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</u>");
  end();
});

(0, _tap.test)("empty", function (_ref1090) {
  var similar = _ref1090.similar,
      end = _ref1090.end;

  similar((0, _.ul)(), { sel: "ul" });
  end();
});

(0, _tap.test)("selector", function (_ref1091) {
  var similar = _ref1091.similar,
      end = _ref1091.end;

  similar((0, _.ul)({ selector: ".value" }), { sel: "ul.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1092) {
  var similar = _ref1092.similar,
      end = _ref1092.end;

  similar((0, _.ul)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1093) {
  var similar = _ref1093.similar,
      end = _ref1093.end;

  similar((0, _.ul)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1094) {
  var similar = _ref1094.similar,
      end = _ref1094.end;

  similar((0, _.ul)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1095) {
  var similar = _ref1095.similar,
      end = _ref1095.end;

  similar((0, _.ul)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1096) {
  var similar = _ref1096.similar,
      end = _ref1096.end;

  similar((0, _.ul)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1097) {
  var similar = _ref1097.similar,
      end = _ref1097.end;

  similar((0, _.ul)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1098) {
  var similar = _ref1098.similar,
      end = _ref1098.end;

  similar((0, _.ul)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "ul#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1099) {
  var equal = _ref1099.equal,
      end = _ref1099.end;

  equal((0, _snabbdomToHtml2.default)((0, _.ul)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ul id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</ul>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1100) {
  var equal = _ref1100.equal,
      end = _ref1100.end;

  equal(toHTMLWithPlugins((0, _.ul)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<ul id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</ul>");
  end();
});

(0, _tap.test)("empty", function (_ref1101) {
  var similar = _ref1101.similar,
      end = _ref1101.end;

  similar((0, _._var)(), { sel: "var" });
  end();
});

(0, _tap.test)("selector", function (_ref1102) {
  var similar = _ref1102.similar,
      end = _ref1102.end;

  similar((0, _._var)({ selector: ".value" }), { sel: "var.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1103) {
  var similar = _ref1103.similar,
      end = _ref1103.end;

  similar((0, _._var)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1104) {
  var similar = _ref1104.similar,
      end = _ref1104.end;

  similar((0, _._var)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1105) {
  var similar = _ref1105.similar,
      end = _ref1105.end;

  similar((0, _._var)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1106) {
  var similar = _ref1106.similar,
      end = _ref1106.end;

  similar((0, _._var)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1107) {
  var similar = _ref1107.similar,
      end = _ref1107.end;

  similar((0, _._var)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1108) {
  var similar = _ref1108.similar,
      end = _ref1108.end;

  similar((0, _._var)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1109) {
  var similar = _ref1109.similar,
      end = _ref1109.end;

  similar((0, _._var)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "var#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1110) {
  var equal = _ref1110.equal,
      end = _ref1110.end;

  equal((0, _snabbdomToHtml2.default)((0, _._var)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<var id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</var>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1111) {
  var equal = _ref1111.equal,
      end = _ref1111.end;

  equal(toHTMLWithPlugins((0, _._var)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<var id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</var>");
  end();
});

(0, _tap.test)("empty", function (_ref1112) {
  var similar = _ref1112.similar,
      end = _ref1112.end;

  similar((0, _.video)(), { sel: "video" });
  end();
});

(0, _tap.test)("selector", function (_ref1113) {
  var similar = _ref1113.similar,
      end = _ref1113.end;

  similar((0, _.video)({ selector: ".value" }), { sel: "video.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1114) {
  var similar = _ref1114.similar,
      end = _ref1114.end;

  similar((0, _.video)({ children: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("children array string", function (_ref1115) {
  var similar = _ref1115.similar,
      end = _ref1115.end;

  similar((0, _.video)({ children: ["test"] }), { children: [{ text: "test" }] });
  end();
});

(0, _tap.test)("children function", function (_ref1116) {
  var similar = _ref1116.similar,
      end = _ref1116.end;

  similar((0, _.video)({ children: Function }), { children: [Function] });
  end();
});

(0, _tap.test)("children array function", function (_ref1117) {
  var similar = _ref1117.similar,
      end = _ref1117.end;

  similar((0, _.video)({ children: [Function] }), { children: [Function] });
  end();
});

(0, _tap.test)("aria", function (_ref1118) {
  var similar = _ref1118.similar,
      end = _ref1118.end;

  similar((0, _.video)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1119) {
  var similar = _ref1119.similar,
      end = _ref1119.end;

  similar((0, _.video)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1120) {
  var similar = _ref1120.similar,
      end = _ref1120.end;

  similar((0, _.video)({
    "selector": "#b.c.d",
    "children": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "video#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1121) {
  var equal = _ref1121.equal,
      end = _ref1121.end;

  equal((0, _snabbdomToHtml2.default)((0, _.video)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<video id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</video>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1122) {
  var equal = _ref1122.equal,
      end = _ref1122.end;

  equal(toHTMLWithPlugins((0, _.video)({
    "selector": "#b.c.d",
    "children": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<video id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</video>");
  end();
});

(0, _tap.test)("empty", function (_ref1123) {
  var similar = _ref1123.similar,
      end = _ref1123.end;

  similar((0, _.area)(), { sel: "area" });
  end();
});

(0, _tap.test)("selector", function (_ref1124) {
  var similar = _ref1124.similar,
      end = _ref1124.end;

  similar((0, _.area)({ selector: ".value" }), { sel: "area.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1125) {
  var throws = _ref1125.throws,
      end = _ref1125.end;

  throws(function () {
    return (0, _.area)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1126) {
  var throws = _ref1126.throws,
      end = _ref1126.end;

  throws(function () {
    return (0, _.area)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1127) {
  var throws = _ref1127.throws,
      end = _ref1127.end;

  throws(function () {
    return (0, _.area)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1128) {
  var throws = _ref1128.throws,
      end = _ref1128.end;

  throws(function () {
    return (0, _.area)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1129) {
  var similar = _ref1129.similar,
      end = _ref1129.end;

  similar((0, _.area)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1130) {
  var similar = _ref1130.similar,
      end = _ref1130.end;

  similar((0, _.area)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1131) {
  var similar = _ref1131.similar,
      end = _ref1131.end;

  similar((0, _.area)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "area#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1132) {
  var equal = _ref1132.equal,
      end = _ref1132.end;

  equal((0, _snabbdomToHtml2.default)((0, _.area)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<area id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1133) {
  var equal = _ref1133.equal,
      end = _ref1133.end;

  equal(toHTMLWithPlugins((0, _.area)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<area id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1134) {
  var similar = _ref1134.similar,
      end = _ref1134.end;

  similar((0, _.base)(), { sel: "base" });
  end();
});

(0, _tap.test)("selector", function (_ref1135) {
  var similar = _ref1135.similar,
      end = _ref1135.end;

  similar((0, _.base)({ selector: ".value" }), { sel: "base.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1136) {
  var throws = _ref1136.throws,
      end = _ref1136.end;

  throws(function () {
    return (0, _.base)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1137) {
  var throws = _ref1137.throws,
      end = _ref1137.end;

  throws(function () {
    return (0, _.base)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1138) {
  var throws = _ref1138.throws,
      end = _ref1138.end;

  throws(function () {
    return (0, _.base)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1139) {
  var throws = _ref1139.throws,
      end = _ref1139.end;

  throws(function () {
    return (0, _.base)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1140) {
  var similar = _ref1140.similar,
      end = _ref1140.end;

  similar((0, _.base)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1141) {
  var similar = _ref1141.similar,
      end = _ref1141.end;

  similar((0, _.base)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1142) {
  var similar = _ref1142.similar,
      end = _ref1142.end;

  similar((0, _.base)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "base#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1143) {
  var equal = _ref1143.equal,
      end = _ref1143.end;

  equal((0, _snabbdomToHtml2.default)((0, _.base)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<base id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1144) {
  var equal = _ref1144.equal,
      end = _ref1144.end;

  equal(toHTMLWithPlugins((0, _.base)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<base id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1145) {
  var similar = _ref1145.similar,
      end = _ref1145.end;

  similar((0, _.br)(), { sel: "br" });
  end();
});

(0, _tap.test)("selector", function (_ref1146) {
  var similar = _ref1146.similar,
      end = _ref1146.end;

  similar((0, _.br)({ selector: ".value" }), { sel: "br.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1147) {
  var throws = _ref1147.throws,
      end = _ref1147.end;

  throws(function () {
    return (0, _.br)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1148) {
  var throws = _ref1148.throws,
      end = _ref1148.end;

  throws(function () {
    return (0, _.br)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1149) {
  var throws = _ref1149.throws,
      end = _ref1149.end;

  throws(function () {
    return (0, _.br)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1150) {
  var throws = _ref1150.throws,
      end = _ref1150.end;

  throws(function () {
    return (0, _.br)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1151) {
  var similar = _ref1151.similar,
      end = _ref1151.end;

  similar((0, _.br)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1152) {
  var similar = _ref1152.similar,
      end = _ref1152.end;

  similar((0, _.br)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1153) {
  var similar = _ref1153.similar,
      end = _ref1153.end;

  similar((0, _.br)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "br#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1154) {
  var equal = _ref1154.equal,
      end = _ref1154.end;

  equal((0, _snabbdomToHtml2.default)((0, _.br)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<br id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1155) {
  var equal = _ref1155.equal,
      end = _ref1155.end;

  equal(toHTMLWithPlugins((0, _.br)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<br id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1156) {
  var similar = _ref1156.similar,
      end = _ref1156.end;

  similar((0, _.col)(), { sel: "col" });
  end();
});

(0, _tap.test)("selector", function (_ref1157) {
  var similar = _ref1157.similar,
      end = _ref1157.end;

  similar((0, _.col)({ selector: ".value" }), { sel: "col.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1158) {
  var throws = _ref1158.throws,
      end = _ref1158.end;

  throws(function () {
    return (0, _.col)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1159) {
  var throws = _ref1159.throws,
      end = _ref1159.end;

  throws(function () {
    return (0, _.col)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1160) {
  var throws = _ref1160.throws,
      end = _ref1160.end;

  throws(function () {
    return (0, _.col)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1161) {
  var throws = _ref1161.throws,
      end = _ref1161.end;

  throws(function () {
    return (0, _.col)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1162) {
  var similar = _ref1162.similar,
      end = _ref1162.end;

  similar((0, _.col)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1163) {
  var similar = _ref1163.similar,
      end = _ref1163.end;

  similar((0, _.col)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1164) {
  var similar = _ref1164.similar,
      end = _ref1164.end;

  similar((0, _.col)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "col#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1165) {
  var equal = _ref1165.equal,
      end = _ref1165.end;

  equal((0, _snabbdomToHtml2.default)((0, _.col)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<col id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1166) {
  var equal = _ref1166.equal,
      end = _ref1166.end;

  equal(toHTMLWithPlugins((0, _.col)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<col id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1167) {
  var similar = _ref1167.similar,
      end = _ref1167.end;

  similar((0, _.embed)(), { sel: "embed" });
  end();
});

(0, _tap.test)("selector", function (_ref1168) {
  var similar = _ref1168.similar,
      end = _ref1168.end;

  similar((0, _.embed)({ selector: ".value" }), { sel: "embed.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1169) {
  var throws = _ref1169.throws,
      end = _ref1169.end;

  throws(function () {
    return (0, _.embed)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1170) {
  var throws = _ref1170.throws,
      end = _ref1170.end;

  throws(function () {
    return (0, _.embed)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1171) {
  var throws = _ref1171.throws,
      end = _ref1171.end;

  throws(function () {
    return (0, _.embed)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1172) {
  var throws = _ref1172.throws,
      end = _ref1172.end;

  throws(function () {
    return (0, _.embed)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1173) {
  var similar = _ref1173.similar,
      end = _ref1173.end;

  similar((0, _.embed)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1174) {
  var similar = _ref1174.similar,
      end = _ref1174.end;

  similar((0, _.embed)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1175) {
  var similar = _ref1175.similar,
      end = _ref1175.end;

  similar((0, _.embed)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "embed#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1176) {
  var equal = _ref1176.equal,
      end = _ref1176.end;

  equal((0, _snabbdomToHtml2.default)((0, _.embed)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<embed id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1177) {
  var equal = _ref1177.equal,
      end = _ref1177.end;

  equal(toHTMLWithPlugins((0, _.embed)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<embed id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1178) {
  var similar = _ref1178.similar,
      end = _ref1178.end;

  similar((0, _.hr)(), { sel: "hr" });
  end();
});

(0, _tap.test)("selector", function (_ref1179) {
  var similar = _ref1179.similar,
      end = _ref1179.end;

  similar((0, _.hr)({ selector: ".value" }), { sel: "hr.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1180) {
  var throws = _ref1180.throws,
      end = _ref1180.end;

  throws(function () {
    return (0, _.hr)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1181) {
  var throws = _ref1181.throws,
      end = _ref1181.end;

  throws(function () {
    return (0, _.hr)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1182) {
  var throws = _ref1182.throws,
      end = _ref1182.end;

  throws(function () {
    return (0, _.hr)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1183) {
  var throws = _ref1183.throws,
      end = _ref1183.end;

  throws(function () {
    return (0, _.hr)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1184) {
  var similar = _ref1184.similar,
      end = _ref1184.end;

  similar((0, _.hr)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1185) {
  var similar = _ref1185.similar,
      end = _ref1185.end;

  similar((0, _.hr)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1186) {
  var similar = _ref1186.similar,
      end = _ref1186.end;

  similar((0, _.hr)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "hr#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1187) {
  var equal = _ref1187.equal,
      end = _ref1187.end;

  equal((0, _snabbdomToHtml2.default)((0, _.hr)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<hr id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1188) {
  var equal = _ref1188.equal,
      end = _ref1188.end;

  equal(toHTMLWithPlugins((0, _.hr)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<hr id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1189) {
  var similar = _ref1189.similar,
      end = _ref1189.end;

  similar((0, _.img)(), { sel: "img" });
  end();
});

(0, _tap.test)("selector", function (_ref1190) {
  var similar = _ref1190.similar,
      end = _ref1190.end;

  similar((0, _.img)({ selector: ".value" }), { sel: "img.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1191) {
  var throws = _ref1191.throws,
      end = _ref1191.end;

  throws(function () {
    return (0, _.img)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1192) {
  var throws = _ref1192.throws,
      end = _ref1192.end;

  throws(function () {
    return (0, _.img)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1193) {
  var throws = _ref1193.throws,
      end = _ref1193.end;

  throws(function () {
    return (0, _.img)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1194) {
  var throws = _ref1194.throws,
      end = _ref1194.end;

  throws(function () {
    return (0, _.img)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1195) {
  var similar = _ref1195.similar,
      end = _ref1195.end;

  similar((0, _.img)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1196) {
  var similar = _ref1196.similar,
      end = _ref1196.end;

  similar((0, _.img)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1197) {
  var similar = _ref1197.similar,
      end = _ref1197.end;

  similar((0, _.img)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "img#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1198) {
  var equal = _ref1198.equal,
      end = _ref1198.end;

  equal((0, _snabbdomToHtml2.default)((0, _.img)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<img id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1199) {
  var equal = _ref1199.equal,
      end = _ref1199.end;

  equal(toHTMLWithPlugins((0, _.img)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<img id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1200) {
  var similar = _ref1200.similar,
      end = _ref1200.end;

  similar((0, _.input)(), { sel: "input" });
  end();
});

(0, _tap.test)("selector", function (_ref1201) {
  var similar = _ref1201.similar,
      end = _ref1201.end;

  similar((0, _.input)({ selector: ".value" }), { sel: "input.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1202) {
  var throws = _ref1202.throws,
      end = _ref1202.end;

  throws(function () {
    return (0, _.input)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1203) {
  var throws = _ref1203.throws,
      end = _ref1203.end;

  throws(function () {
    return (0, _.input)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1204) {
  var throws = _ref1204.throws,
      end = _ref1204.end;

  throws(function () {
    return (0, _.input)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1205) {
  var throws = _ref1205.throws,
      end = _ref1205.end;

  throws(function () {
    return (0, _.input)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1206) {
  var similar = _ref1206.similar,
      end = _ref1206.end;

  similar((0, _.input)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1207) {
  var similar = _ref1207.similar,
      end = _ref1207.end;

  similar((0, _.input)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1208) {
  var similar = _ref1208.similar,
      end = _ref1208.end;

  similar((0, _.input)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "input#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1209) {
  var equal = _ref1209.equal,
      end = _ref1209.end;

  equal((0, _snabbdomToHtml2.default)((0, _.input)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<input id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1210) {
  var equal = _ref1210.equal,
      end = _ref1210.end;

  equal(toHTMLWithPlugins((0, _.input)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<input id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1211) {
  var similar = _ref1211.similar,
      end = _ref1211.end;

  similar((0, _.link)(), { sel: "link" });
  end();
});

(0, _tap.test)("selector", function (_ref1212) {
  var similar = _ref1212.similar,
      end = _ref1212.end;

  similar((0, _.link)({ selector: ".value" }), { sel: "link.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1213) {
  var throws = _ref1213.throws,
      end = _ref1213.end;

  throws(function () {
    return (0, _.link)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1214) {
  var throws = _ref1214.throws,
      end = _ref1214.end;

  throws(function () {
    return (0, _.link)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1215) {
  var throws = _ref1215.throws,
      end = _ref1215.end;

  throws(function () {
    return (0, _.link)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1216) {
  var throws = _ref1216.throws,
      end = _ref1216.end;

  throws(function () {
    return (0, _.link)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1217) {
  var similar = _ref1217.similar,
      end = _ref1217.end;

  similar((0, _.link)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1218) {
  var similar = _ref1218.similar,
      end = _ref1218.end;

  similar((0, _.link)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1219) {
  var similar = _ref1219.similar,
      end = _ref1219.end;

  similar((0, _.link)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "link#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1220) {
  var equal = _ref1220.equal,
      end = _ref1220.end;

  equal((0, _snabbdomToHtml2.default)((0, _.link)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<link id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1221) {
  var equal = _ref1221.equal,
      end = _ref1221.end;

  equal(toHTMLWithPlugins((0, _.link)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<link id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1222) {
  var similar = _ref1222.similar,
      end = _ref1222.end;

  similar((0, _.meta)(), { sel: "meta" });
  end();
});

(0, _tap.test)("selector", function (_ref1223) {
  var similar = _ref1223.similar,
      end = _ref1223.end;

  similar((0, _.meta)({ selector: ".value" }), { sel: "meta.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1224) {
  var throws = _ref1224.throws,
      end = _ref1224.end;

  throws(function () {
    return (0, _.meta)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1225) {
  var throws = _ref1225.throws,
      end = _ref1225.end;

  throws(function () {
    return (0, _.meta)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1226) {
  var throws = _ref1226.throws,
      end = _ref1226.end;

  throws(function () {
    return (0, _.meta)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1227) {
  var throws = _ref1227.throws,
      end = _ref1227.end;

  throws(function () {
    return (0, _.meta)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1228) {
  var similar = _ref1228.similar,
      end = _ref1228.end;

  similar((0, _.meta)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1229) {
  var similar = _ref1229.similar,
      end = _ref1229.end;

  similar((0, _.meta)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1230) {
  var similar = _ref1230.similar,
      end = _ref1230.end;

  similar((0, _.meta)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "meta#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1231) {
  var equal = _ref1231.equal,
      end = _ref1231.end;

  equal((0, _snabbdomToHtml2.default)((0, _.meta)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<meta id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1232) {
  var equal = _ref1232.equal,
      end = _ref1232.end;

  equal(toHTMLWithPlugins((0, _.meta)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<meta id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1233) {
  var similar = _ref1233.similar,
      end = _ref1233.end;

  similar((0, _.param)(), { sel: "param" });
  end();
});

(0, _tap.test)("selector", function (_ref1234) {
  var similar = _ref1234.similar,
      end = _ref1234.end;

  similar((0, _.param)({ selector: ".value" }), { sel: "param.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1235) {
  var throws = _ref1235.throws,
      end = _ref1235.end;

  throws(function () {
    return (0, _.param)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1236) {
  var throws = _ref1236.throws,
      end = _ref1236.end;

  throws(function () {
    return (0, _.param)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1237) {
  var throws = _ref1237.throws,
      end = _ref1237.end;

  throws(function () {
    return (0, _.param)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1238) {
  var throws = _ref1238.throws,
      end = _ref1238.end;

  throws(function () {
    return (0, _.param)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1239) {
  var similar = _ref1239.similar,
      end = _ref1239.end;

  similar((0, _.param)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1240) {
  var similar = _ref1240.similar,
      end = _ref1240.end;

  similar((0, _.param)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1241) {
  var similar = _ref1241.similar,
      end = _ref1241.end;

  similar((0, _.param)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "param#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1242) {
  var equal = _ref1242.equal,
      end = _ref1242.end;

  equal((0, _snabbdomToHtml2.default)((0, _.param)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<param id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1243) {
  var equal = _ref1243.equal,
      end = _ref1243.end;

  equal(toHTMLWithPlugins((0, _.param)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<param id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1244) {
  var similar = _ref1244.similar,
      end = _ref1244.end;

  similar((0, _.source)(), { sel: "source" });
  end();
});

(0, _tap.test)("selector", function (_ref1245) {
  var similar = _ref1245.similar,
      end = _ref1245.end;

  similar((0, _.source)({ selector: ".value" }), { sel: "source.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1246) {
  var throws = _ref1246.throws,
      end = _ref1246.end;

  throws(function () {
    return (0, _.source)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1247) {
  var throws = _ref1247.throws,
      end = _ref1247.end;

  throws(function () {
    return (0, _.source)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1248) {
  var throws = _ref1248.throws,
      end = _ref1248.end;

  throws(function () {
    return (0, _.source)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1249) {
  var throws = _ref1249.throws,
      end = _ref1249.end;

  throws(function () {
    return (0, _.source)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1250) {
  var similar = _ref1250.similar,
      end = _ref1250.end;

  similar((0, _.source)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1251) {
  var similar = _ref1251.similar,
      end = _ref1251.end;

  similar((0, _.source)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1252) {
  var similar = _ref1252.similar,
      end = _ref1252.end;

  similar((0, _.source)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "source#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1253) {
  var equal = _ref1253.equal,
      end = _ref1253.end;

  equal((0, _snabbdomToHtml2.default)((0, _.source)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<source id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1254) {
  var equal = _ref1254.equal,
      end = _ref1254.end;

  equal(toHTMLWithPlugins((0, _.source)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<source id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1255) {
  var similar = _ref1255.similar,
      end = _ref1255.end;

  similar((0, _.track)(), { sel: "track" });
  end();
});

(0, _tap.test)("selector", function (_ref1256) {
  var similar = _ref1256.similar,
      end = _ref1256.end;

  similar((0, _.track)({ selector: ".value" }), { sel: "track.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1257) {
  var throws = _ref1257.throws,
      end = _ref1257.end;

  throws(function () {
    return (0, _.track)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1258) {
  var throws = _ref1258.throws,
      end = _ref1258.end;

  throws(function () {
    return (0, _.track)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1259) {
  var throws = _ref1259.throws,
      end = _ref1259.end;

  throws(function () {
    return (0, _.track)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1260) {
  var throws = _ref1260.throws,
      end = _ref1260.end;

  throws(function () {
    return (0, _.track)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1261) {
  var similar = _ref1261.similar,
      end = _ref1261.end;

  similar((0, _.track)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1262) {
  var similar = _ref1262.similar,
      end = _ref1262.end;

  similar((0, _.track)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1263) {
  var similar = _ref1263.similar,
      end = _ref1263.end;

  similar((0, _.track)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "track#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1264) {
  var equal = _ref1264.equal,
      end = _ref1264.end;

  equal((0, _snabbdomToHtml2.default)((0, _.track)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<track id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1265) {
  var equal = _ref1265.equal,
      end = _ref1265.end;

  equal(toHTMLWithPlugins((0, _.track)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<track id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("empty", function (_ref1266) {
  var similar = _ref1266.similar,
      end = _ref1266.end;

  similar((0, _.wbr)(), { sel: "wbr" });
  end();
});

(0, _tap.test)("selector", function (_ref1267) {
  var similar = _ref1267.similar,
      end = _ref1267.end;

  similar((0, _.wbr)({ selector: ".value" }), { sel: "wbr.value" });
  end();
});

(0, _tap.test)("children string", function (_ref1268) {
  var throws = _ref1268.throws,
      end = _ref1268.end;

  throws(function () {
    return (0, _.wbr)({ children: "test" });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array string", function (_ref1269) {
  var throws = _ref1269.throws,
      end = _ref1269.end;

  throws(function () {
    return (0, _.wbr)({ children: ["test"] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children function", function (_ref1270) {
  var throws = _ref1270.throws,
      end = _ref1270.end;

  throws(function () {
    return (0, _.wbr)({ children: Function });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("children array function", function (_ref1271) {
  var throws = _ref1271.throws,
      end = _ref1271.end;

  throws(function () {
    return (0, _.wbr)({ children: [Function] });
  }, { message: "Empty tags cannot semantically have children." });
  end();
});

(0, _tap.test)("aria", function (_ref1272) {
  var similar = _ref1272.similar,
      end = _ref1272.end;

  similar((0, _.wbr)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref1273) {
  var similar = _ref1273.similar,
      end = _ref1273.end;

  similar((0, _.wbr)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref1274) {
  var similar = _ref1274.similar,
      end = _ref1274.end;

  similar((0, _.wbr)({
    "selector": "#b.c.d",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "wbr#b.c.d",
    data: {
      "attrs": {
        "yyy": "y",
        "xxx": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: undefined,
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref1275) {
  var equal = _ref1275.equal,
      end = _ref1275.end;

  equal((0, _snabbdomToHtml2.default)((0, _.wbr)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<wbr id=\"b\" class=\"c d active\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">");
  end();
});

(0, _tap.test)("html with plugins", function (_ref1276) {
  var equal = _ref1276.equal,
      end = _ref1276.end;

  equal(toHTMLWithPlugins((0, _.wbr)({
    "selector": "#b.c.d",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { xxx: "x" },
    "attrs": { yyy: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<wbr id=\"b\" class=\"c d active\" title=\"x\" href=\"/a\" yyy=\"y\" xxx=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">");
  end();
});